@@ -45,12 +45,12 @@
 #include <unistd.h>
 
 
-// Returns the system time, in milliseconds.
-long timeGetTime()
+// Returns the system time, in seconds.
+double timeGetTime()
 {
     struct timeval tp;
     gettimeofday( &tp, 0 );
-    return (tp.tv_sec * 1000) + (tp.tv_usec / 1000);
+    return (double)tp.tv_sec + (double)tp.tv_usec / 1000000;
 }
 
 
@@ -458,7 +458,8 @@ void wisp::drawAsBackground()
 
 
 EuphoriaWidget::EuphoriaWidget( QWidget* parent, const char* name )
-              : QGLWidget(parent, name), _wisps(0), _backwisps(0)
+              : QGLWidget(parent, name), texName(0), _wisps(0), _backwisps(0),
+	      feedbackmap(0), feedbacktex(0)
 {
     setDefaults( Regular );
 
@@ -471,6 +472,10 @@ EuphoriaWidget::EuphoriaWidget( QWidget* parent, const char* name )
 EuphoriaWidget::~EuphoriaWidget()
 {
 	// Free memory
+	if ( texName )
+		glDeleteTextures( 1, &texName );
+	if ( feedbacktex )
+		glDeleteTextures( 1, &feedbacktex );
 	delete[] _wisps;
 	delete[] _backwisps;
 }
@@ -479,15 +484,11 @@ EuphoriaWidget::~EuphoriaWidget()
 void EuphoriaWidget::paintGL()
 {
 	int i;
-	static long thisTime = timeGetTime(), lastTime;
+	static double lastTime = timeGetTime();
 
 	// update time
-	lastTime = thisTime;
-    thisTime = timeGetTime();
-    if(thisTime >= lastTime) 
-		elapsedTime = float(thisTime - lastTime) * 0.001f;
-    // else use elapsedTime from last frame
-
+	elapsedTime = timeGetTime() - lastTime;
+	lastTime += elapsedTime;
 
     _ec = this;
 
@@ -500,7 +501,7 @@ void EuphoriaWidget::paintGL()
 
 	if(dFeedback)
     {
-		static float feedbackIntensity = float(dFeedback) / 101.0f;
+		float feedbackIntensity = float(dFeedback) / 101.0f;
 
 		// update feedback variables
 		for(i=0; i<4; i++)
@@ -624,7 +625,9 @@ void EuphoriaWidget::resizeGL( int w, int h )
 // Window initialization
 void EuphoriaWidget::initializeGL()
 {
-    //resizeGL( width(), height() );
+    // Need to call this to setup viewport[] parameters used in
+    // the next updateParameters() call
+    resizeGL( width(), height() );
 
     updateParameters();
 
@@ -706,6 +709,9 @@ void EuphoriaWidget::updateParameters()
 		case 3:
 			gluBuild2DMipmaps(GL_TEXTURE_2D, 1, TEXSIZE, TEXSIZE, GL_LUMINANCE, GL_UNSIGNED_BYTE, linesmap);
 		}
+	} else if ( texName ) {
+		glDeleteTextures( 1, &texName );
+		texName = 0;
 	}
 
 	if(dFeedback)
@@ -718,6 +724,7 @@ void EuphoriaWidget::updateParameters()
 
 		// feedback texture setup
 		glEnable(GL_TEXTURE_2D);
+		delete [] feedbackmap;
 		feedbackmap = new unsigned char[feedbacktexsize*feedbacktexsize*3];
 		glGenTextures(1, &feedbacktex);
 		glBindTexture(GL_TEXTURE_2D, feedbacktex);
@@ -735,6 +742,9 @@ void EuphoriaWidget::updateParameters()
 		lv[0] = float(dFeedbackspeed) * (myRandf(0.0025f) + 0.0025f);
 		lv[1] = float(dFeedbackspeed) * (myRandf(0.0025f) + 0.0025f);
 		lv[2] = float(dFeedbackspeed) * (myRandf(0.0025f) + 0.0025f);
+	} else if ( feedbacktex ) {
+		glDeleteTextures( 1, &feedbacktex );
+		feedbacktex = 0;
 	}
 
 	// Initialize wisps
@@ -957,10 +967,8 @@ void KEuphoriaScreenSaver::setMode( int id )
 
 
 #include <qlayout.h>
-#include <qpushbutton.h>
 #include <qlabel.h>
 #include <qcombobox.h>
-#include <kbuttonbox.h>
 #include <kmessagebox.h>
 
 
@@ -981,75 +989,42 @@ static const char* defaultText[] =
 
 
 KEuphoriaSetup::KEuphoriaSetup( QWidget* parent, const char* name )
-                      : QDialog( parent, name )
+        : KDialogBase( parent, name, true, i18n("Setup Euphoria Screen Saver"),
+          Ok|Cancel|Help, Ok, true )
 {
-    setCaption( i18n("Setup Euphoria Screen Saver") );
-
-    QVBoxLayout* top    = new QVBoxLayout(this, 10, 10);
-    QHBoxLayout* across = new QHBoxLayout;
-    top->addLayout( across );
+    setButtonText( Help, i18n( "A&bout" ) );
 
+    QWidget *main = makeMainWidget();
 
+    QHBoxLayout* top    = new QHBoxLayout(main, 0, spacingHint());
     QVBoxLayout* leftCol = new QVBoxLayout;
-    across->addLayout( leftCol );
+    top->addLayout( leftCol );
 
-    leftCol->addStretch( 1 );
+    QLabel* label = new QLabel( i18n("Mode:"), main );
+    leftCol->addWidget( label );
 
-
-    // Parameters
-    QHBoxLayout* lo = new QHBoxLayout;
-    leftCol->addLayout(lo);
-
-    lo->addStretch(1);
-
-    QLabel* label = new QLabel( i18n("Mode:"), this );
-    label->setAlignment( AlignVCenter | AlignRight );
-    lo->addWidget( label );
-
-    modeW = new QComboBox( this );
+    modeW = new QComboBox( main );
     int i = 0;
     while (defaultText[i])
         modeW->insertItem( i18n(defaultText[i++]) );
-    lo->addWidget( modeW );
-
-    lo->addStretch(1);
-
-    leftCol->addStretch( 1 );
-
+    leftCol->addWidget( modeW );
 
+    leftCol->addStretch();
 
     // Preview
     QWidget* preview;
-    preview = new QWidget( this );
+    preview = new QWidget( main );
     preview->setFixedSize( 220, 170 );
     preview->setBackgroundColor( black );
     preview->show();    // otherwise saver does not get correct size
     _saver = new KEuphoriaScreenSaver( preview->winId() );
-    across->addWidget(preview);
+    top->addWidget(preview);
 
     // Now that we have _saver...
     modeW->setCurrentItem( _saver->mode() );    // set before we connect
     connect( modeW, SIGNAL(activated(int)), _saver, SLOT(setMode(int)) );
 
-
-    // Buttons
-    QPushButton* button;
-    KButtonBox* bbox = new KButtonBox(this);
-    button = bbox->addButton( i18n("&About"));
-    connect( button, SIGNAL(clicked()), SLOT(aboutPressed()) );
-
-    bbox->addStretch(1);
-
-    button = bbox->addButton( i18n("&OK"));
-    connect( button, SIGNAL(clicked()), SLOT(slotOkPressed()) );
-
-    button = bbox->addButton(i18n("&Cancel"));
-    connect( button, SIGNAL(clicked()), SLOT(reject()) );
-    bbox->layout();
-    top->addWidget(bbox);
-
-
-    top->freeze();
+    setMinimumSize( sizeHint() );
 }
 
 
@@ -1059,7 +1034,7 @@ KEuphoriaSetup::~KEuphoriaSetup()
 }
 
 
-void KEuphoriaSetup::aboutPressed()
+void KEuphoriaSetup::slotHelp()
 {
     KMessageBox::about(this, 
         i18n("<h3>Euphoria 1.0</h3>\n<p>Copyright (c) 2002 Terence M. Welsh<br>\n<a href=\"http://www.reallyslick.com/\">http://www.reallyslick.com/</a></p>\n\n<p>Ported to KDE by Karl Robillard</p>"),
@@ -1070,7 +1045,7 @@ void KEuphoriaSetup::aboutPressed()
 /**
   Ok pressed - save settings and exit
 */
-void KEuphoriaSetup::slotOkPressed()
+void KEuphoriaSetup::slotOk()
 {
     KConfig* config = KGlobal::config();
     config->setGroup("Settings");
