@@ -868,76 +868,40 @@ static const char* defaultText[] =
 
 
 KFluxSetup::KFluxSetup( QWidget* parent, const char* name )
-                      : QDialog( parent, name )
+    : KDialogBase( parent, name, true, i18n( "Setup Flux Screen Saver" ),
+      Ok|Cancel|Help, Ok, true )
 {
-    setCaption( i18n("Setup Flux Screen Saver") );
-
-    QVBoxLayout* top    = new QVBoxLayout(this, 10, 10);
-    QHBoxLayout* across = new QHBoxLayout;
-    top->addLayout( across );
-
+    setButtonText( Help, i18n( "A&bout" ) );
+    QWidget *main = makeMainWidget();
 
+    QHBoxLayout* top = new QHBoxLayout( main, 0, spacingHint() );
     QVBoxLayout* leftCol = new QVBoxLayout;
-    across->addLayout( leftCol );
-
-    leftCol->addStretch( 1 );
-
+    top->addLayout( leftCol );
 
     // Parameters
-    QHBoxLayout* lo = new QHBoxLayout;
-    leftCol->addLayout(lo);
+    QLabel* label = new QLabel( i18n("Mode:"), main );
+    leftCol->addWidget( label );
 
-    lo->addStretch(1);
-
-    QLabel* label = new QLabel( i18n("Mode:"), this );
-    label->setAlignment( AlignVCenter | AlignRight );
-    lo->addWidget( label );
-
-    modeW = new QComboBox( this );
+    modeW = new QComboBox( main );
     int i = 0;
     while (defaultText[i])
         modeW->insertItem( i18n(defaultText[i++]) );
-    lo->addWidget( modeW );
-
-    lo->addStretch(1);
-
-    leftCol->addStretch( 1 );
-
+    leftCol->addWidget( modeW );
 
+    leftCol->addStretch();
 
     // Preview
     QWidget* preview;
-    preview = new QWidget( this );
-    preview->setFixedSize( 220, 170 );
-    //preview->setFixedSize( 640, 480 );
+    preview = new QWidget( main );
+    preview->setFixedSize( 220, 165 );
     preview->setBackgroundColor( black );
     preview->show();    // otherwise saver does not get correct size
     _saver = new KFluxScreenSaver( preview->winId() );
-    across->addWidget(preview);
+    top->addWidget(preview);
 
     // Now that we have _saver...
     modeW->setCurrentItem( _saver->mode() );    // set before we connect
     connect( modeW, SIGNAL(activated(int)), _saver, SLOT(setMode(int)) );
-
-
-    // Buttons
-    QPushButton* button;
-    KButtonBox* bbox = new KButtonBox(this);
-    button = bbox->addButton( i18n("About"));
-    connect( button, SIGNAL(clicked()), SLOT(aboutPressed()) );
-
-    bbox->addStretch(1);
-
-    button = bbox->addButton( i18n("OK"));
-    connect( button, SIGNAL(clicked()), SLOT(slotOkPressed()) );
-
-    button = bbox->addButton(i18n("Cancel"));
-    connect( button, SIGNAL(clicked()), SLOT(reject()) );
-    bbox->layout();
-    top->addWidget(bbox);
-
-
-    top->freeze();
 }
 
 
@@ -947,7 +911,7 @@ KFluxSetup::~KFluxSetup()
 }
 
 
-void KFluxSetup::aboutPressed()
+void KFluxSetup::slotHelp()
 {
     KMessageBox::about(this, 
         i18n("<h3>Flux 1.0</h3>\n<p>Copyright (c) 2002 Terence M. Welsh<br>\n<a href=\"http://www.reallyslick.com/\">http://www.reallyslick.com/</a></p>\n\n<p>Ported to KDE by Karl Robillard</p>"),
@@ -958,7 +922,7 @@ void KFluxSetup::aboutPressed()
 /**
   Ok pressed - save settings and exit
 */
-void KFluxSetup::slotOkPressed()
+void KFluxSetup::slotOk()
 {
     KConfig* config = KGlobal::config();
     config->setGroup("Settings");
