@@ -11,18 +11,17 @@
 //		changed horizontal step size to reduce jerkyness,
 //		text will return to right margin immediately (and not be drawn half a screen width off-screen)
 //		Harald H.-J. Bongartz <harald@bongartz.org>
+// 2003/09/06 Converted to use KDialogBase - Nadeem Hasan <nhasan@kde.org>
 #include <stdlib.h>
 
-#include <qcolor.h>
 #include <qlabel.h>
-#include <qscrollbar.h>
+#include <qlineedit.h>
 #include <qcombobox.h>
 #include <qcheckbox.h>
 #include <qgroupbox.h>
 #include <qslider.h>
 #include <qlayout.h>
 #include <qdatetime.h>
-#include <qpushbutton.h>
 #include <qfontdatabase.h>
 #include <qpainter.h>
 
@@ -31,7 +30,6 @@
 #include <kglobal.h>
 #include <klocale.h>
 #include <kconfig.h>
-#include <kbuttonbox.h>
 #include <kmessagebox.h>
 #include <kcolorbutton.h>
 #include <kfontcombo.h>
@@ -60,36 +58,30 @@ extern "C"
 //-----------------------------------------------------------------------------
 
 KBannerSetup::KBannerSetup( QWidget *parent, const char *name )
-	: QDialog( parent, name, TRUE )
-,ed(0)
+	: KDialogBase( parent, name, true, i18n( "Setup Banner Screen Saver" ),
+	  Ok|Cancel|Help, Ok, true ), saver( 0 ), ed(0), speed( 50 )
 {
-	saver = NULL;
-	speed = 50;
-
+	setButtonText( Help, i18n( "A&bout" ) );
 	readSettings();
 
-	QString str;
+    QWidget *main = makeMainWidget();
+
 	QLabel *label;
-	QPushButton *button;
-	QSlider *sb;
 
-	setCaption( i18n("Setup Banner Screen Saver") );
-
-	QVBoxLayout *tl = new QVBoxLayout(this, 10, 10);
-	QHBoxLayout *tl1 = new QHBoxLayout;
+	QVBoxLayout *tl = new QVBoxLayout(main, 0, spacingHint());
+	QHBoxLayout *tl1 = new QHBoxLayout( 0, 0, spacingHint() );
 	tl->addLayout(tl1);
-	QVBoxLayout *tl11 = new QVBoxLayout(5);
+	QVBoxLayout *tl11 = new QVBoxLayout( 0, 0, spacingHint() );
 	tl1->addLayout(tl11);
 
-	QGroupBox *group = new QGroupBox( i18n("Font"), this );
-	QGridLayout *gl = new QGridLayout(group, 6, 2, 5);
-	gl->addRowSpacing(0, 10);
+	QGroupBox *group = new QGroupBox( 0, Vertical, i18n("Font"), main );
+	QGridLayout *gl = new QGridLayout(group->layout(), 6, 2, spacingHint() );
 
 	label = new QLabel( i18n("Family:"), group );
 	gl->addWidget(label, 1, 0);
 
 	KFontCombo* comboFonts = new KFontCombo( QFontDatabase().families(), group );
-        comboFonts->setCurrentFont( fontFamily );
+	comboFonts->setCurrentFont( fontFamily );
 	gl->addWidget(comboFonts, 1, 1);
 	connect( comboFonts, SIGNAL( activated( const QString& ) ),
 			SLOT( slotFamily( const QString& ) ) );
@@ -97,10 +89,12 @@ KBannerSetup::KBannerSetup( QWidget *parent, const char *name )
 	label = new QLabel( i18n("Size:"), group );
 	gl->addWidget(label, 2, 0);
 
-	comboSizes = new QComboBox( FALSE, group );
+	comboSizes = new QComboBox( TRUE, group );
         fillFontSizes();
 	gl->addWidget(comboSizes, 2, 1);
 	connect( comboSizes, SIGNAL( activated( int ) ), SLOT( slotSize( int ) ) );
+	connect( comboSizes, SIGNAL( textChanged( const QString & ) ),
+			SLOT( slotSizeEdit( const QString &  ) ) );
 
 	QCheckBox *cb = new QCheckBox( i18n("Bold"),
 				       group );
@@ -127,7 +121,7 @@ KBannerSetup::KBannerSetup( QWidget *parent, const char *name )
    connect(cyclingColorCb,SIGNAL(toggled(bool)),this,SLOT(slotCyclingColor(bool)));
    cyclingColorCb->setChecked(cyclingColor);
 
-	preview = new QWidget( this );
+	preview = new QWidget( main );
 	preview->setFixedSize( 220, 170 );
 	preview->setBackgroundColor( black );
 	preview->show();    // otherwise saver does not get correct size
@@ -136,11 +130,11 @@ KBannerSetup::KBannerSetup( QWidget *parent, const char *name )
 
 	tl11->addWidget(group);
 
-	label = new QLabel( i18n("Speed:"), this );
+	label = new QLabel( i18n("Speed:"), main );
 	tl11->addStretch(1);
 	tl11->addWidget(label);
 
-	sb = new QSlider(0, 100, 10, speed, QSlider::Horizontal, this );
+	QSlider *sb = new QSlider(0, 100, 10, speed, QSlider::Horizontal, main );
 	sb->setMinimumWidth( 180);
 	sb->setFixedHeight(20);
     sb->setTickmarks(QSlider::Below);
@@ -151,35 +145,22 @@ KBannerSetup::KBannerSetup( QWidget *parent, const char *name )
 	QHBoxLayout *tl2 = new QHBoxLayout;
 	tl->addLayout(tl2);
 
-	label = new QLabel( i18n("Message:"), this );
+	label = new QLabel( i18n("Message:"), main );
 	tl2->addWidget(label);
 
-	ed = new QLineEdit( this );
+	ed = new QLineEdit( main );
 	tl2->addWidget(ed);
 	ed->setText( message );
 	connect( ed, SIGNAL( textChanged( const QString & ) ),
 			SLOT( slotMessage( const QString &  ) ) );
 
-   QCheckBox *timeCb=new QCheckBox( i18n("Show current time"),this);
+   QCheckBox *timeCb=new QCheckBox( i18n("Show current time"), main);
    timeCb->setFixedSize(timeCb->sizeHint());
    tl->addWidget(timeCb,0,Qt::AlignLeft);
    connect(timeCb,SIGNAL(toggled(bool)),this,SLOT(slotTimeToggled(bool)));
    timeCb->setChecked(showTime);
 
-   KButtonBox *bbox = new KButtonBox(this);
-	button = bbox->addButton( i18n("&About"));
-	connect( button, SIGNAL( clicked() ), SLOT(slotAbout() ) );
-	bbox->addStretch(1);
-
-	button = bbox->addButton( i18n("&OK"));
-	connect( button, SIGNAL( clicked() ), SLOT( slotOkPressed() ) );
-
-	button = bbox->addButton(i18n("&Cancel"));
-	connect( button, SIGNAL( clicked() ), SLOT( reject() ) );
-	bbox->layout();
-	tl->addWidget(bbox);
-
-	tl->freeze();
+   tl->addStretch();
 }
 
 // read settings from config file
@@ -195,19 +176,12 @@ void KBannerSetup::readSettings()
 		speed = 50;*/
 
    message=config->readEntry("Message","KDE");
-
    showTime=config->readBoolEntry("ShowTime",FALSE);
-
    fontFamily=config->readEntry("FontFamily",(QApplication::font()).family());
-
    fontSize=config->readNumEntry("FontSize",48);
-
    fontColor.setNamedColor(config->readEntry("FontColor","red"));
-
    cyclingColor=config->readBoolEntry("CyclingColor",FALSE);
-
    bold=config->readBoolEntry("FontBold",FALSE);
-
    italic=config->readBoolEntry("FontItalic",FALSE);
 }
 
@@ -218,19 +192,28 @@ void KBannerSetup::fillFontSizes()
     comboSizes->clear();
     int i = 0;
     sizes = QFontDatabase().pointSizes( fontFamily );
-    sizes << 96 << 0;
+    sizes << 96 << 128 << 156 << 0;
     int current = 0;
     while ( sizes[i] )
 	{
 	QString num;
 	num.setNum( sizes[i] );
 	comboSizes->insertItem( num, i );
-	if ( fontSize >= sizes[i] )
-                current = i;
+	if ( fontSize == sizes[i] ) // fontsize equals one of the defined ones
+	    {
+            current = i;
+	    comboSizes->setCurrentItem( current );
+	    slotSize( current );
+	    }
 	i++;
 	}
-    comboSizes->setCurrentItem( current );
-    slotSize( current );
+    if ( current == 0 ) // fontsize seems to be entered by hand
+        {
+	QString fsize;
+	fsize.setNum( fontSize );
+	comboSizes->setEditText(fsize);
+	slotSizeEdit( fsize );
+	}
     comboSizes->blockSignals( block );
 }
 
@@ -249,6 +232,15 @@ void KBannerSetup::slotSize( int indx )
 		saver->setFont( fontFamily, fontSize, fontColor, bold, italic );
 }
 
+void KBannerSetup::slotSizeEdit( const QString& fs )
+{
+	bool ok;
+        fontSize = fs.toInt( &ok, 10 );
+	if ( ok )
+		if ( saver )
+			saver->setFont( fontFamily, fontSize, fontColor, bold, italic );
+}
+
 void KBannerSetup::slotColor( const QColor &col )
 {
     fontColor = col;
@@ -309,19 +301,21 @@ void KBannerSetup::slotTimeToggled( bool on )
 }
 
 // Ok pressed - save settings and exit
-void KBannerSetup::slotOkPressed()
+void KBannerSetup::slotOk()
 {
-    KConfig *config = KGlobal::config();
+	KConfig *config = KGlobal::config();
 	config->setGroup( "Settings" );
 
 	config->writeEntry( "Speed", speed );
-
 	config->writeEntry( "Message", message );
 	config->writeEntry( "ShowTime", showTime );
-
 	config->writeEntry( "FontFamily", fontFamily );
 
 	QString fsize;
+	if (fontSize == 0) // an non-number was entered in the font size combo
+	{
+		fontSize = 48;
+	}
 	fsize.setNum( fontSize );
 	config->writeEntry( "FontSize", fsize );
 
@@ -330,7 +324,6 @@ void KBannerSetup::slotOkPressed()
 		fontColor.blue() );
 	config->writeEntry( "FontColor", colName );
 	config->writeEntry( "CyclingColor", cyclingColor );
-
 	config->writeEntry( "FontBold", bold );
 	config->writeEntry( "FontItalic", italic );
 
@@ -339,10 +332,10 @@ void KBannerSetup::slotOkPressed()
 	accept();
 }
 
-void KBannerSetup::slotAbout()
+void KBannerSetup::slotHelp()
 {
 	KMessageBox::about(this,
-			     i18n("Banner Version 2.2.0\n\nWritten by Martin R. Jones 1996\nmjones@kde.org\nExtended by Alexander Neundorf 2000\nalexander.neundorf@rz.tu-ilmenau.de\n"));
+			     i18n("Banner Version 2.2.1\n\nWritten by Martin R. Jones 1996\nmjones@kde.org\nExtended by Alexander Neundorf 2000\nalexander.neundorf@rz.tu-ilmenau.de\n"));
 }
 
 //-----------------------------------------------------------------------------
@@ -457,12 +450,12 @@ void KBannerSaver::initialize()
 	fsize = fontSize * height() / QApplication::desktop()->height();
 
 	font = QFont( fontFamily, fsize, bold ? QFont::Bold : QFont::Normal, italic );
-    
+
 	pixmapSize = QSize();
 
 	xpos = width();
 	ypos = fsize + (int) ((double)(height()-fsize)*krnd->getDouble());
-	step = 2 * width() / QApplication::desktop()->width(); // 6 -> 2 -hhjb- 
+	step = 2 * width() / QApplication::desktop()->width(); // 6 -> 2 -hhjb-
 	if ( step == 0 )
 		step = 1;
 }
@@ -501,7 +494,7 @@ void KBannerSaver::slotTimeout()
 	xpos = width();
 	ypos = fsize + (int) ((double)(height()-2.0*fsize)*krnd->getDouble());
     }
-	
+
     bitBlt( this, xpos, ypos, &pixmap, 0, 0, pixmapSize.width(), pixmapSize.height());
 }
 
