@@ -9,15 +9,14 @@
 #define __BANNER_H__
 
 #include <qtimer.h>
-#include <qptrlist.h>
-#include <qdialog.h>
-#include <qlineedit.h>
-#include <kscreensaver.h>
 
+#include <kscreensaver.h>
+#include <kdialogbase.h>
 
 #define SATURATION 100
 #define VALUE 255
 
+class QLineEdit;
 class KColorButton;
 class KRandomSequence;
 
@@ -65,7 +64,7 @@ protected:
 };
 
 
-class KBannerSetup : public QDialog
+class KBannerSetup : public KDialogBase
 {
     Q_OBJECT
 public:
@@ -78,14 +77,15 @@ protected:
 private slots:
     void slotFamily( const QString & );
     void slotSize( int );
+    void slotSizeEdit(const QString &);
     void slotColor(const QColor &);
     void slotCyclingColor(bool on);
     void slotBold( bool );
     void slotItalic( bool );
     void slotSpeed( int );
     void slotMessage( const QString & );
-    void slotOkPressed();
-    void slotAbout();
+    void slotOk();
+    void slotHelp();
     void slotTimeToggled(bool on);
 
 private:
