@@ -24,20 +24,16 @@
 
 #include <qcolor.h>
 #include <qlabel.h>
-#include <qpushbutton.h>
-#include <qscrollbar.h>
-#include <qlineedit.h>
 #include <qlistbox.h>
 #include <qlayout.h>
 #include <qpainter.h>
 #include <qpixmap.h>
 #include <qimage.h>
-#include <qvalidator.h>
 
 #include <kapplication.h>
 #include <kconfig.h>
 #include <kmessagebox.h>
-#include <kbuttonbox.h>
+#include <knuminput.h>
 #include <klocale.h>
 #include <kglobal.h>
 #include <krandomsequence.h>
@@ -267,7 +263,7 @@ void KBlobSaver::lnNextFrame()
 			dir = -1;
 		else
 			dir = 1;
-		ln_xinc = SMALLRAND(3.0)*dir;
+		ln_xinc = SMALLRAND(3)*dir;
 	}
 	if (ty+dim+ln_yinc > (int)height()-1 || ty+ln_yinc < 0)
 	{
@@ -275,7 +271,7 @@ void KBlobSaver::lnNextFrame()
 			dir = -1;
 		else
 			dir = 1;
-		ln_yinc = SMALLRAND(2.0)*dir;
+		ln_yinc = SMALLRAND(2)*dir;
 	}
 
 	// move box to new position
@@ -439,54 +435,46 @@ KBlobSetup::KBlobSetup
 	QWidget *parent,
 	const char *name
 )
-: QDialog( parent, name, TRUE )
+: KDialogBase( parent, name, true, i18n( "Setup Blob Screen Saver" ),
+	Ok|Cancel|Help, Ok, true )
 {
-  QLabel *label;
 
-  initAlg();
-	QPushButton *button;
-	QString str;
+	initAlg();
 
 	// get saver configuration from kde registry
 	readSettings();
 
-	setCaption(i18n("Setup Blob Screen Saver"));
+	setButtonText( Help, i18n( "A&bout" ) );
+	QWidget *main = makeMainWidget();
 
-	QVBoxLayout *tl = new QVBoxLayout(this, 10);
-	QHBoxLayout *tl1 = new QHBoxLayout;
-	tl->addLayout(tl1);
+	QHBoxLayout *tl = new QHBoxLayout( main, 0, spacingHint() );
 
-	QVBoxLayout *tl11 = new QVBoxLayout(5);
-	tl1->addLayout(tl11);
+	QVBoxLayout *vbox = new QVBoxLayout;
+	tl->addLayout(vbox);
 
 	// seconds to generate on a frame
-	label = new QLabel(i18n("Frame show (secs):"),
-		    this);
-	stime = new QLineEdit(this);
-        stime->setValidator(new QIntValidator(stime));
-	str.setNum(showtime);
-	stime->setText(str);
-	tl11->addWidget(label);
-	tl11->addWidget(stime);
-	tl11->addSpacing(10);
+	QLabel *label = new QLabel(i18n("Frame duration:"), main);
+	stime = new KIntNumInput( showtime, main );
+	stime->setSuffix( i18n( " sec" ) );
+	vbox->addWidget(label);
+	vbox->addWidget(stime);
 
 	// available algorithms
-	label = new QLabel(i18n("Algorithm:"), this);
-	algs = new QListBox(this);
+	label = new QLabel(i18n("Algorithm:"), main);
+	algs = new QListBox(main);
 	algs->setMinimumSize(150, 105);
 	for (int i = 0; i <= ALG_RANDOM; i++)
 		algs->insertItem(alg_str[i]);
 	algs->setCurrentItem(alg);
-	tl11->addWidget(label);
-	tl11->addWidget(algs);
-	tl11->addStretch(1);
+	vbox->addWidget(label);
+	vbox->addWidget(algs);
 
 	// preview window
-	QWidget *preview = new QWidget( this );
+	QWidget *preview = new QWidget( main );
 	preview->setFixedSize(220, 170);
 	preview->setBackgroundColor(black);
 	preview->show();
-	tl1->addWidget(preview);
+	tl->addWidget(preview);
 	saver = new KBlobSaver(preview->winId());
 	saver->setDimension(3);
 	if (QPixmap::defaultDepth() > 8)
@@ -494,28 +482,11 @@ KBlobSetup::KBlobSetup
 	else
 		saver->setColorInc(4);
 
+	tl->addStretch();
+
 	// so selecting an algorithm will start previewing that alg
 	connect(algs, SIGNAL(highlighted(int)), saver,
 		SLOT(setAlgorithm(int)));
-
-	KButtonBox *bbox = new KButtonBox(this);
-
-	// show an address to send flame mail to
-	button = bbox->addButton( i18n("About"));
-	connect( button, SIGNAL( clicked() ), SLOT(slotAbout() ) );
-	bbox->addStretch(1);
-
-	// means attempt to register settings with kde registry
-	button = bbox->addButton( i18n("&OK"));
-	connect( button, SIGNAL( clicked() ), SLOT( slotOkPressed() ) );
-
-	// ignore changes
-	button = bbox->addButton(i18n("&Cancel"));
-	connect( button, SIGNAL( clicked() ), SLOT( reject() ) );
-	bbox->layout();
-	tl->addWidget(bbox);
-
-	tl->freeze();
 }
 
 void KBlobSetup::readSettings()
@@ -531,13 +502,13 @@ void KBlobSetup::readSettings()
 }
 
 // Ok pressed - save settings and exit
-void KBlobSetup::slotOkPressed()
+void KBlobSetup::slotOk()
 {
     KConfig *config = KGlobal::config();
 
     config->setGroup("Settings");
 
-    config->writeEntry("Showtime", stime->text());
+    config->writeEntry("Showtime", stime->value());
     config->writeEntry("Algorithm", algs->currentItem());
 
     config->sync();
@@ -545,7 +516,7 @@ void KBlobSetup::slotOkPressed()
     accept();
 }
 
-void KBlobSetup::slotAbout()
+void KBlobSetup::slotHelp()
 {
 	KMessageBox::about(this,
 			     i18n("Blobsaver Version 0.1\n\nWritten by Tiaan Wessels 1997\ntiaan@netsys.co.za"));
