@@ -58,7 +58,7 @@ KFountainSetup::KFountainSetup( QWidget *parent, const char *name )
 	//QLabel *label;
 	//QPushButton *button;
 
-	//setCaption( i18n("Setup The Particle Fountain") );
+	//setCaption( i18n("Setup Particle Fountain") );
 
 	//QVBoxLayout *tl = new QVBoxLayout(this, 10);
 	//QHBoxLayout *tl1 = new QHBoxLayout;
@@ -291,13 +291,13 @@ void Fountain::initializeGL ()
 		{
 			particle[loop].active=true;				// Make All The Particles Active
 			particle[loop].life=1.0f;				// Give All The Particles Full Life
-			particle[loop].fade=float(rand()%100)/1000.0f+0.003f;	// Random Fade Speed
+			particle[loop].fade=float(KApplication::random()%100)/1000.0f+0.003f;	// Random Fade Speed
 			particle[loop].r=colors[(loop+1)/(MAX_PARTICLES/12)][0];	// Select Red Rainbow Color
 			particle[loop].g=colors[(loop+1)/(MAX_PARTICLES/12)][1];	// Select Green Rainbow Color
 			particle[loop].b=colors[(loop+1)/(MAX_PARTICLES/12)][2];	// Select Blue Rainbow Color
-			particle[loop].xi=float((rand()%50)-26.0f)*10.0f;	// Random Speed On X Axis
-			particle[loop].yi=float((rand()%50)-25.0f)*10.0f;	// Random Speed On Y Axis
-			particle[loop].zi=float((rand()%50)-25.0f)*10.0f;	// Random Speed On Z Axis
+			particle[loop].xi=float((KApplication::random()%50)-26.0f)*10.0f;	// Random Speed On X Axis
+			particle[loop].yi=float((KApplication::random()%50)-25.0f)*10.0f;	// Random Speed On Y Axis
+			particle[loop].zi=float((KApplication::random()%50)-25.0f)*10.0f;	// Random Speed On Z Axis
 			particle[loop].xg=0.0f;					// Set Horizontal Pull To Zero
 			particle[loop].yg=-0.8f;				// Set Vertical Pull Downward
 			particle[loop].zg=0.0f;					// Set Pull On Z Axis To Zero
@@ -396,13 +396,13 @@ void Fountain::paintGL ()
 			if (particle[loop].life<0.0f)					// If Particle Is Burned Out
 			{
 				particle[loop].life=2.0f;				// Give It New Life
-				particle[loop].fade=float(rand()%100)/1000.0f+0.003f;	// Random Fade Value
+				particle[loop].fade=float(KApplication::random()%100)/1000.0f+0.003f;	// Random Fade Value
 				particle[loop].x=0.0f;					// Center On X Axis
 				particle[loop].y=0.0f;					// Center On Y Axis
 				particle[loop].z=0.0f;					// Center On Z Axis
-				particle[loop].xi=xspeed+float((rand()%60)-32.0f);	// X Axis Speed And Direction
-				particle[loop].yi=yspeed+float((rand()%60)-30.0f);	// Y Axis Speed And Direction
-				particle[loop].zi=float((rand()%60)-30.0f);		// Z Axis Speed And Direction
+				particle[loop].xi=xspeed+float((KApplication::random()%60)-32.0f);	// X Axis Speed And Direction
+				particle[loop].yi=yspeed+float((KApplication::random()%60)-30.0f);	// Y Axis Speed And Direction
+				particle[loop].zi=float((KApplication::random()%60)-30.0f);		// Z Axis Speed And Direction
 				particle[loop].r=colors[col][0];			// Select Red From Color Table
 				particle[loop].g=colors[col][1];			// Select Green From Color Table
 				particle[loop].b=colors[col][2];			// Select Blue From Color Table
@@ -412,13 +412,13 @@ void Fountain::paintGL ()
 				// Explode
 					particle[loop].active=true;				// Make All The Particles Active
 					particle[loop].life=1.0f;				// Give All The Particles Full Life
-					particle[loop].fade=float(rand()%100)/1000.0f+0.003f;	// Random Fade Speed
+					particle[loop].fade=float(KApplication::random()%100)/1000.0f+0.003f;	// Random Fade Speed
 					particle[loop].r=colors[(loop+1)/(MAX_PARTICLES/12)][0];	// Select Red Rainbow Color
 					particle[loop].g=colors[(loop+1)/(MAX_PARTICLES/12)][1];	// Select Green Rainbow Color
 					particle[loop].b=colors[(loop+1)/(MAX_PARTICLES/12)][2];	// Select Blue Rainbow Color
-					particle[loop].xi=float((rand()%50)-26.0f)*10.0f;	// Random Speed On X Axis
-					particle[loop].yi=float((rand()%50)-25.0f)*10.0f;	// Random Speed On Y Axis
-					particle[loop].zi=float((rand()%50)-25.0f)*10.0f;	// Random Speed On Z Axis
+					particle[loop].xi=float((KApplication::random()%50)-26.0f)*10.0f;	// Random Speed On X Axis
+					particle[loop].yi=float((KApplication::random()%50)-25.0f)*10.0f;	// Random Speed On Y Axis
+					particle[loop].zi=float((KApplication::random()%50)-25.0f)*10.0f;	// Random Speed On Z Axis
 					particle[loop].xg=0.0f;					// Set Horizontal Pull To Zero
 					particle[loop].yg=-0.8f;				// Set Vertical Pull Downward
 					particle[loop].zg=0.0f;					// Set Pull On Z Axis To Zero
