@@ -67,6 +67,11 @@ KGravitySetup::KGravitySetup( QWidget *parent, const char *name )
 
 }
 
+KGravitySetup::~KGravitySetup()
+{
+    delete saver;
+}
+
 // read settings from config file
 void KGravitySetup::readSettings()
 {
@@ -301,11 +306,14 @@ void Gravity::paintGL ()
 	//glRotatef(transIndex, 1,0,0);
 	//glRotatef(transIndex, 0,1,0);
 	//glRotatef(transIndex, 0,0,1);
-	float xmax = 10.0;
-	float ymax = 15.0;
+	float xmax = 5.0;
+	float ymax = 5.0;
+	float zmax = 5.0;
 	glTranslatef( GLfloat(xmax*sin(3.14*transIndex/360)-xmax),
 			GLfloat(ymax*cos(3.14*transIndex/360)-ymax),
 			0.0 );
+	//glRotatef(transIndex, 0,GLfloat(zmax*cos(3.14*transIndex/360000)), GLfloat(zmax*cos(3.14*transIndex/360000)));
+
 	for (loop=0;loop<MAX_PARTICLES;loop++)				// Loop Through All The Particles
 	{
 		if (particle[loop].active)				// If The Particle Is Active
@@ -343,7 +351,7 @@ void Gravity::paintGL ()
 			glVertex3f( x - particle[loop].size, y - particle[loop].size, z );
 		glEnd( );
 			particle[loop].x=(particle[loop].xo*sin(particle[loop].index))*pow((double) particle[loop].index/particle[loop].indexo,(double) 8.0);
-			particle[loop].y=(particle[loop].yo*cos(particle[loop].index))*pow((double) particle[loop].index/particle[loop].indexo,(double) 8.0);
+			particle[loop].y=(particle[loop].yo*sin(particle[loop].index))*pow((double) particle[loop].index/particle[loop].indexo,(double) 8.0);
 			particle[loop].z=(particle[loop].zo*sin(particle[loop].index))*pow((double) particle[loop].index/particle[loop].indexo,(double) 8.0);
 			particle[loop].index-=0.05;
 			if (particle[loop].index<0.0f )			// If Particle Is Burned Out
@@ -382,18 +390,18 @@ void Gravity::buildParticle(int loop)
 	{0.5f,0.5f,1.0f},{0.75f,0.5f,1.0f},{1.0f,0.5f,1.0f},{1.0f,0.5f,0.75f}};
 	col = ( ++col ) % 12;
 	particle[loop].active=true;
-	particle[loop].index=rand()%100;
+	particle[loop].index=KApplication::random()%100;
 	particle[loop].indexo=particle[loop].index;
-	particle[loop].fade=float(rand()%100)/1000.0f+0.003f;	// Random Fade Value
+	particle[loop].fade=float(KApplication::random()%100)/1000.0f+0.003f;	// Random Fade Value
 	particle[loop].r=colors[col][0];			// Select Red From Color Table
 	particle[loop].g=colors[col][1];			// Select Green From Color Table
 	particle[loop].b=colors[col][2];			// Select Blue From Color Table
 	particle[loop].size=size;
-	particle[loop].x = float(rand()%100-50)*4.0;
-	particle[loop].y = float(rand()%20-10)*4.0;
-	particle[loop].z = float(rand()%100-50)*4.0;
+	particle[loop].x = float(KApplication::random()%100-50)*4.0;
+	particle[loop].y = float(KApplication::random()%20-10)*4.0;
+	particle[loop].z = float(KApplication::random()%100-50)*4.0;
 	particle[loop].xo = particle[loop].x;
-	if ((1+(rand() % 10) > 5))
+	if ((1+(KApplication::random() % 10) > 5))
 		particle[loop].yo = particle[loop].y;
 	else
 		particle[loop].yo = 0.0;
