@@ -1,4 +1,4 @@
-//-----------------------------------------------------------------------------
+///-----------------------------------------------------------------------------
 //
 // kgravity - Partical gravity Screen Saver for KDE 2
 //
@@ -26,7 +26,7 @@
 #include <qfile.h>
 #include <qtextstream.h>
 
-#define	MAX_PARTICLES	1000
+#define	MAX_PARTICLES	100
 
 
 class Gravity : public QGLWidget
@@ -115,6 +115,7 @@ class KGravitySetup : public SetupUi
 	Q_OBJECT
 public:
 	KGravitySetup( QWidget *parent = NULL, const char *name = NULL );
+    ~KGravitySetup();
 
 protected:
 	void readSettings();
