@@ -17,7 +17,7 @@
  * the above copyright notice appear in all copies and that both that
  * copyright notice and this permission notice appear in supporting
  * documentation.  No representations are made about the suitability of this
- * software for any purpose.  It is provided "as is" without express or 
+ * software for any purpose.  It is provided "as is" without express or
  * implied warranty.
  *
  */
@@ -33,19 +33,14 @@
 /* for AIX at least */
 #include <time.h>
 
-#include <qbuttongroup.h>
 #include <qcolor.h>
 #include <qlabel.h>
 #include <qlayout.h>
-#include <qradiobutton.h>
-#include <qpushbutton.h>
 #include <qslider.h>
 #include <qpainter.h>
 #include <qbitmap.h>
 
 #include <kapplication.h>
-#include <kbuttonbox.h>
-#include <kcolordialog.h>
 #include <kconfig.h>
 #include <klocale.h>
 #include <kglobal.h>
@@ -116,7 +111,7 @@ init_pool ( QWidget *w )
   state->grid_margin_x = w->width()%state->char_width/2;
   state->grid_margin_y = w->height()%state->char_height/2;
   state->show_threads = 1;
-  vm_init_pool( &(state->pool), state->grid_width*state->grid_height, 
+  vm_init_pool( &(state->pool), state->grid_width*state->grid_height,
                 THREAD_MAX_STACK_SIZE, MAX_THREADS_NUM );
    //vm_enable_reverse( state->pool, 1 );
    state->modified = new char[state->grid_height*state->grid_width];
@@ -130,7 +125,7 @@ draw_pool (m_state *state)
 {
   int x, y;
   struct tvm_process*	curr_thread;
-  
+
   if( state->show_threads ) {
    curr_thread = state->pool->processes;
    while( curr_thread ) {
@@ -246,7 +241,7 @@ int kVmSaver::getRandom( const int max_value ) {
 void kVmSaver::modifyArea( const int op ) {
  int position;
 
- vm_modify( pool_state->pool, position = 
+ vm_modify( pool_state->pool, position =
             getRandom(pool_state->pool->area_size - 1), op );
  pool_state->modified[position] = 1;
 }
@@ -279,73 +274,57 @@ void kVmSaver::slotTimeout()
 //-----------------------------------------------------------------------------
 
 kVmSetup::kVmSetup( QWidget *parent, const char *name )
-	: QDialog( parent, name, TRUE )
+	: KDialogBase( parent, name, true, i18n( "Setup Virtual Machine" ),
+	  Ok|Cancel|Help, Ok, true )
 {
 	readSettings();
 
-	setCaption( i18n("Setup Virtual Machine Screen Saver") );
+	setButtonText( Help, i18n( "A&bout" ) );
+	QWidget *main = makeMainWidget();
 
-	QLabel *label;
-	QPushButton *button;
-	QSlider *slider;
-
-	QVBoxLayout *tl = new QVBoxLayout(this, 10, 10);
-	QHBoxLayout *tl1 = new QHBoxLayout;
+	QHBoxLayout *tl = new QHBoxLayout( main, 0, spacingHint() );
+	QVBoxLayout *tl1 = new QVBoxLayout();
 	tl->addLayout(tl1);
-	QVBoxLayout *tl11 = new QVBoxLayout(5);
-	tl1->addLayout(tl11);	
 
-	label = new QLabel( i18n("Virtual machine speed:"), this );
-	tl11->addWidget(label);
+	QLabel *label = new QLabel( i18n("Virtual machine speed:"), main );
+	tl1->addWidget(label);
 
-	slider = new QSlider( QSlider::Horizontal, this );
-	slider->setMinimumSize( 90, 20 );
+	QSlider *slider = new QSlider( QSlider::Horizontal, main );
+	slider->setMinimumSize( 120, 20 );
 	slider->setRange( 0, 100 );
 	slider->setSteps( 10, 20 );
+	slider->setTickmarks( QSlider::Below );
+	slider->setTickInterval( 10 );
 	slider->setValue( speed );
-	connect( slider, SIGNAL( valueChanged( int ) ), 
+	connect( slider, SIGNAL( valueChanged( int ) ),
 		 SLOT( slotSpeed( int ) ) );
-	tl11->addWidget(slider);
-	tl11->addStretch(1);
+	tl1->addWidget(slider);
 
-	label = new QLabel( i18n("Display update speed:"), this );
-	tl11->addWidget(label);
+	label = new QLabel( i18n("Display update speed:"), main );
+	tl1->addWidget(label);
 
-	slider = new QSlider( QSlider::Horizontal, this );
-	slider->setMinimumSize( 90, 20 );
+	slider = new QSlider( QSlider::Horizontal, main );
+	slider->setMinimumSize( 120, 20 );
 	slider->setRange( 0, MAX_REFRESH_TIMEOUT );
 	slider->setSteps( MAX_REFRESH_TIMEOUT/10, MAX_REFRESH_TIMEOUT/5 );
+	slider->setTickmarks( QSlider::Below );
+	slider->setTickInterval( MAX_REFRESH_TIMEOUT/10 );
 	slider->setValue( MAX_REFRESH_TIMEOUT - refreshTimeout );
-	connect( slider, SIGNAL( valueChanged( int ) ), 
+	connect( slider, SIGNAL( valueChanged( int ) ),
 		 SLOT( slotRefreshTimeout( int ) ) );
-	tl11->addWidget(slider);
-	tl11->addStretch(1);
+	tl1->addWidget(slider);
+	tl1->addStretch();
 
-  QFrame *frame = new QFrame( this );
-  frame->setFixedSize( 224, 174 );
-  frame->setFrameStyle(QFrame::Panel | QFrame::Sunken);
-  frame->setLineWidth(2);
-	preview = new QWidget( frame );
-	preview->setFixedSize( 220, 170 );
-	preview->setBackgroundColor( black );
+	preview = new QWidget( main );
+	preview->setFixedSize( 220, 165 );
 	preview->show();    // otherwise saver does not get correct size
 	saver = new kVmSaver( preview->winId() );
-	tl1->addWidget(frame);
+	tl->addWidget(preview);
+}
 
-	KButtonBox *bbox = new KButtonBox(this);	
-	button = bbox->addButton( i18n("&About"));
-	connect( button, SIGNAL( clicked() ), SLOT(slotAbout() ) );
-	bbox->addStretch(1);
-
-	button = bbox->addButton( i18n("&OK"));	
-	connect( button, SIGNAL( clicked() ), SLOT( slotOkPressed() ) );
-
-	button = bbox->addButton(i18n("&Cancel"));
-	connect( button, SIGNAL( clicked() ), SLOT( reject() ) );
-	bbox->layout();
-	tl->addWidget(bbox);
-
-	tl->freeze();
+kVmSetup::~kVmSetup()
+{
+    delete saver;
 }
 
 void kVmSetup::readSettings()
@@ -378,7 +357,7 @@ void kVmSetup::slotRefreshTimeout( int num )
 		saver->setRefreshTimeout( refreshTimeout );
 }
 
-void kVmSetup::slotOkPressed()
+void kVmSetup::slotOk()
 {
 	KConfig *config = KGlobal::config();
 	config->setGroup( "Settings" );
@@ -393,7 +372,7 @@ void kVmSetup::slotOkPressed()
 	accept();
 }
 
-void kVmSetup::slotAbout()
+void kVmSetup::slotHelp()
 {
 	KMessageBox::about(this,
 		i18n("Virtual Machine Version 0.1\n\nCopyright (c) 2000 Artur Rataj <art@zeus.polsl.gliwice.pl>\n"),
