@@ -13,7 +13,6 @@
 
 #include <qpainter.h>
 #include <qslider.h>
-#include <qpushbutton.h>
 #include <qlayout.h>
 #include <qcolor.h>
 #include <qlabel.h>
@@ -22,7 +21,6 @@
 #include <klocale.h>
 #include <kglobal.h>
 #include <kconfig.h>
-#include <kbuttonbox.h>
 #include <kmessagebox.h>
 
 #include "lorenz.h"
@@ -69,112 +67,89 @@ extern "C"
 // dialog to setup screen saver parameters
 //
 KLorenzSetup::KLorenzSetup( QWidget *parent, const char *name )
-    : QDialog( parent, name, TRUE )
+    : KDialogBase( parent, name, true, i18n( "Setup Lorenz Attractorr" ),
+      Ok|Cancel|Default|Help, Ok, true )
 {
     readSettings();
 
-    setCaption( i18n("Setup Lorenz Attractor Screen Saver") );
+    setButtonText( Help, i18n( "A&bout" ) );
+    QWidget *main = makeMainWidget();
 
-    QLabel *label;
-    QPushButton *button;
-    QSlider *slider;
-
-    QVBoxLayout *tl = new QVBoxLayout(this, 10, 10);
-    QHBoxLayout *tl1 = new QHBoxLayout;
+    QHBoxLayout *tl = new QHBoxLayout( main, 0, spacingHint() );
+    QVBoxLayout *tl1 = new QVBoxLayout;
     tl->addLayout(tl1);
-    QVBoxLayout *tl11 = new QVBoxLayout(5);
-    tl1->addLayout(tl11);
 
-    label = new QLabel( i18n("Speed:"), this );
-    tl11->addWidget(label);
+    QLabel *label = new QLabel( i18n("Speed:"), main );
+    tl1->addWidget(label);
 
-    sps = slider = new QSlider(MINSPEED, MAXSPEED, 10, speed, QSlider::Horizontal, this);
-    slider->setMinimumSize( 90, 20 );
-    slider->setTickmarks(QSlider::Below);
-    slider->setTickInterval(100);
-    connect( slider, SIGNAL( valueChanged( int ) ), SLOT( slotSpeed( int ) ) );
-    tl11->addWidget(slider);
-    tl11->addSpacing(5);
+    sps = new QSlider(MINSPEED, MAXSPEED, 10, speed, QSlider::Horizontal, main);
+    sps->setMinimumSize( 120, 20 );
+    sps->setTickmarks(QSlider::Below);
+    sps->setTickInterval(150);
+    connect( sps, SIGNAL( valueChanged( int ) ), SLOT( slotSpeed( int ) ) );
+    tl1->addWidget(sps);
 
-    label = new QLabel( i18n("Epoch:"), this );
-    tl11->addWidget(label);
+    label = new QLabel( i18n("Epoch:"), main );
+    tl1->addWidget(label);
 
-    eps = slider = new QSlider(MINEPOCH, MAXEPOCH, 100, epoch, QSlider::Horizontal, this);
-    slider->setMinimumSize( 90, 20 );
-    slider->setTickmarks(QSlider::Below);
-    slider->setTickInterval(3000);
-    connect( slider, SIGNAL( valueChanged( int ) ), SLOT( slotEpoch( int ) ) );
-    tl11->addWidget(slider);
-    tl11->addSpacing(5);
+    eps = new QSlider(MINEPOCH, MAXEPOCH, 100, epoch, QSlider::Horizontal, main);
+    eps->setMinimumSize( 120, 20 );
+    eps->setTickmarks(QSlider::Below);
+    eps->setTickInterval(3000);
+    connect( eps, SIGNAL( valueChanged( int ) ), SLOT( slotEpoch( int ) ) );
+    tl1->addWidget(eps);
 
-    label = new QLabel( i18n("Color rate:"), this );
-    tl11->addWidget(label);
+    label = new QLabel( i18n("Color rate:"), main );
+    tl1->addWidget(label);
 
-    crs = slider = new QSlider(MINCOLOR, MAXCOLOR, 10, crate, QSlider::Horizontal, this);
-    slider->setMinimumSize( 90, 20 );
-    slider->setTickmarks(QSlider::Below);
-    slider->setTickInterval(10);
-    connect( slider, SIGNAL( valueChanged( int ) ), SLOT( slotCRate( int ) ) );
-    tl11->addWidget(slider);
-    tl11->addSpacing(5);
+    crs = new QSlider(MINCOLOR, MAXCOLOR, 5, crate, QSlider::Horizontal, main);
+    crs->setMinimumSize( 120, 20 );
+    crs->setTickmarks(QSlider::Below);
+    crs->setTickInterval(10);
+    connect( crs, SIGNAL( valueChanged( int ) ), SLOT( slotCRate( int ) ) );
+    tl1->addWidget(crs);
 
-    label = new QLabel( i18n("Rotation Z:"), this );
-    tl11->addWidget(label);
+    label = new QLabel( i18n("Rotation Z:"), main );
+    tl1->addWidget(label);
 
-    zrs = slider = new QSlider(MINZROT, MAXZROT, 10, zrot, QSlider::Horizontal, this);
-    slider->setMinimumSize( 90, 20 );
-    slider->setTickmarks(QSlider::Below);
-    slider->setTickInterval(20);
-    connect( slider, SIGNAL( valueChanged( int ) ), SLOT( slotZRot( int ) ) );
-    tl11->addWidget(slider);
-    tl11->addSpacing(5);
+    zrs = new QSlider(MINZROT, MAXZROT, 18, zrot, QSlider::Horizontal, main);
+    zrs->setMinimumSize( 120, 20 );
+    zrs->setTickmarks(QSlider::Below);
+    zrs->setTickInterval(36);
+    connect( zrs, SIGNAL( valueChanged( int ) ), SLOT( slotZRot( int ) ) );
+    tl1->addWidget(zrs);
 
-    label = new QLabel( i18n("Rotation Y:"), this );
-    tl11->addWidget(label);
+    label = new QLabel( i18n("Rotation Y:"), main );
+    tl1->addWidget(label);
 
-    yrs = slider = new QSlider(MINYROT, MAXYROT, 10, yrot, QSlider::Horizontal, this);
-    slider->setMinimumSize( 90, 20 );
-    slider->setTickmarks(QSlider::Below);
-    slider->setTickInterval(20);
-    connect( slider, SIGNAL( valueChanged( int ) ), SLOT( slotYRot( int ) ) );
-    tl11->addWidget(slider);
-    tl11->addSpacing(5);
+    yrs = new QSlider(MINYROT, MAXYROT, 18, yrot, QSlider::Horizontal, main);
+    yrs->setMinimumSize( 120, 20 );
+    yrs->setTickmarks(QSlider::Below);
+    yrs->setTickInterval(36);
+    connect( yrs, SIGNAL( valueChanged( int ) ), SLOT( slotYRot( int ) ) );
+    tl1->addWidget(yrs);
 
-    label = new QLabel( i18n("Rotation X:"), this );
-    tl11->addWidget(label);
+    label = new QLabel( i18n("Rotation X:"), main );
+    tl1->addWidget(label);
 
-    xrs = slider = new QSlider(MINXROT, MAXXROT, 10, xrot, QSlider::Horizontal, this);
-    slider->setMinimumSize( 90, 20 );
-    slider->setTickmarks(QSlider::Below);
-    slider->setTickInterval(20);
-    connect( slider, SIGNAL( valueChanged( int ) ), SLOT( slotXRot( int ) ) );
-    tl11->addWidget(slider);
-    tl11->addStretch(1);
+    xrs = new QSlider(MINXROT, MAXXROT, 18, xrot, QSlider::Horizontal, main);
+    xrs->setMinimumSize( 120, 20 );
+    xrs->setTickmarks(QSlider::Below);
+    xrs->setTickInterval(36);
+    connect( xrs, SIGNAL( valueChanged( int ) ), SLOT( slotXRot( int ) ) );
+    tl1->addWidget(xrs);
 
-    preview = new QWidget( this );
-    preview->setFixedSize( 400, 300 );
+    preview = new QWidget( main );
+    preview->setFixedSize( 220, 165 );
     preview->setBackgroundColor( black );
     preview->show();    // otherwise saver does not get correct size
     saver = new KLorenzSaver( preview->winId() );
-    tl1->addWidget(preview);
+    tl->addWidget(preview);
+}
 
-    KButtonBox *bbox = new KButtonBox(this);
-    button = bbox->addButton( i18n("&About"));
-    connect( button, SIGNAL( clicked() ), SLOT(slotAbout() ) );
-    bbox->addStretch(1);
-
-    button = bbox->addButton( i18n("&OK"));
-    connect( button, SIGNAL( clicked() ), SLOT( slotOkPressed() ) );
-
-    button = bbox->addButton( i18n("&Default"));
-    connect( button, SIGNAL( clicked() ), SLOT( slotDefaultPressed() ) );
-
-    button = bbox->addButton(i18n("&Cancel"));
-    connect( button, SIGNAL( clicked() ), SLOT( reject() ) );
-    bbox->layout();
-    tl->addWidget(bbox);
-
-    tl->freeze();
+KLorenzSetup::~KLorenzSetup()
+{
+    delete saver;
 }
 
 // read settings from config file
@@ -240,13 +215,13 @@ void KLorenzSetup::slotXRot(int num)
     }
 }
 
-void KLorenzSetup::slotAbout()
+void KLorenzSetup::slotHelp()
 {
     KMessageBox::about(this,i18n("Lorenz Attractor screen saver for KDE\n\nCopyright (c) 2000 Nicolas Brodu"));
 }
 
 // Ok pressed - save settings and exit
-void KLorenzSetup::slotOkPressed()
+void KLorenzSetup::slotOk()
 {
     KConfig *config = KGlobal::config();
     config->setGroup( "Settings" );
@@ -263,7 +238,7 @@ void KLorenzSetup::slotOkPressed()
     accept();
 }
 
-void KLorenzSetup::slotDefaultPressed()
+void KLorenzSetup::slotDefault()
 {
     speed = DEFSPEED;
     epoch = DEFEPOCH;
@@ -476,7 +451,8 @@ KLorenzSaver::KLorenzSaver( WId id ) : KScreenSaver( id )
 
 KLorenzSaver::~KLorenzSaver()
 {
-    if (mat) {delete mat; mat=0;} // Overly cautious?
+    delete mat;
+    mat=0;
     timer.stop();
     QColor::leaveAllocContext();
     QColor::destroyAllocContext( colorContext );
@@ -580,7 +556,7 @@ void KLorenzSaver::drawOnce()
         // Apply transform
         mat->transform(x,y,z,kx,ky,kz);
         // Choose a color
-        p.setPen( 
+        p.setPen(
             QColor((int)(sin(t*crate/pi)*127+128),
                    (int)(sin(t*crate/(pi-1))*127+128),
                    (int)(sin(t*crate/(pi-2))*127+128)).pixel() );
