@@ -15,19 +15,14 @@
 #include <qpainter.h>
 #include <qpixmap.h>
 #include <qlabel.h>
-#include <qpushbutton.h>
 #include <qlistbox.h>
 #include <qcheckbox.h>
-#include <qbuttongroup.h>
-#include <qradiobutton.h>
 #include <qslider.h>
 #include <qlayout.h>
 
-#include <kapplication.h> 
+#include <kapplication.h>
 #include <kglobal.h>
-#include <kglobalsettings.h>
-#include <kmessagebox.h> 
-#include <kbuttonbox.h>
+#include <kmessagebox.h>
 #include <klocale.h>
 #include <kconfig.h>
 #include <kstandarddirs.h>
@@ -587,7 +582,7 @@ void KScienceSaver::readSettings()
 
 	vx = copysign( moveX[mode], vx );
 	vy = copysign( moveY[mode], vy );
-}              
+}
 
 void KScienceSaver::do_refresh( const QRect & rect )
 {
@@ -609,7 +604,6 @@ void KScienceSaver::do_refresh( const QRect & rect )
                            rect.left(), rect.top(), 
                            rect.width(), rect.height() );
 	}
-	         
 }
 
 void KScienceSaver::slotTimeout()
@@ -825,7 +819,7 @@ void KScienceSaver::applyLens24bpp(int xs, int ys, int xd, int yd, int w, int h)
 		data += datanext;
 	} 
 }
-                      
+
 void KScienceSaver::applyLens32bpp(int xs, int ys, int xd, int yd, int w, int h)
 {
 	T32bit *off;
@@ -852,144 +846,130 @@ void KScienceSaver::applyLens32bpp(int xs, int ys, int xd, int yd, int w, int h)
 
 //-----------------------------------------------------------------------------
 
-KScienceSetup::KScienceSetup(  QWidget *parent, const char *name ) : 
-               QDialog( parent, name, TRUE )  
+KScienceSetup::KScienceSetup(  QWidget *parent, const char *name )
+	: KDialogBase( parent, name, true, i18n( "Setup Science Screen Saver" ),
+	  Ok|Cancel|Help, Ok, true ), saver( 0 )
 {
-	saver = 0;
-
 	readSettings();
 	initModeInfo();
 
-	setCaption( i18n("Setup Science Screen Saver") );
+	QWidget *main = makeMainWidget();
 
-	QLabel *label;
-	QPushButton *button;
-	QCheckBox *cbox;
-	QSlider *sb;
-	
-	QVBoxLayout *lt  = new QVBoxLayout( this, 10, 10);
-	QHBoxLayout *ltu = new QHBoxLayout() ;
-	lt->addLayout( ltu );
-	QVBoxLayout *ltm = new QVBoxLayout( 5 );
-	ltu->addLayout( ltm );
-	ltu->addSpacing( 5 );
-	QVBoxLayout *ltc = new QVBoxLayout( 5 );
-	ltu->addLayout( ltc );
-	ltu->addSpacing( 5 );
+	QHBoxLayout *lt  = new QHBoxLayout( main, 0, spacingHint());
+	QVBoxLayout *ltm = new QVBoxLayout;
+	lt->addLayout( ltm );
+	QVBoxLayout *ltc = new QVBoxLayout;
+	lt->addLayout( ltc );
 	
 	// mode
-	label = new QLabel( i18n("Mode:"), this );
+	QLabel *label = new QLabel( i18n("Mode:"), main );
 	ltm->addWidget( label );
 
-	QListBox *c = new QListBox( this );
+	QListBox *c = new QListBox( main );
 	for(int i = 0; i<MAX_MODES; i++)
 		c->insertItem( modeInfo[i].name );
 	c->setCurrentItem( mode );
-	c->adjustSize();
 	c->setFixedHeight( 5 * c->fontMetrics().height() );
 	connect( c, SIGNAL( highlighted( int ) ), SLOT( slotMode( int ) ) );
-	ltm->addWidget( c, 2 );
-	ltm->addSpacing( 5 );
+	ltm->addWidget( c );
 
 	// inverse
-	cbox = checkInverse = new QCheckBox( i18n("Inverse"), this );
+	QCheckBox *cbox = checkInverse = new QCheckBox( i18n("Inverse"), main );
 	cbox->setEnabled( modeInfo[mode].inverseEnable );
 	cbox->setChecked( inverse[mode] );
-	cbox->adjustSize();
-	cbox->setMinimumSize( cbox->sizeHint() );
 	connect( cbox, SIGNAL( clicked() ), SLOT( slotInverse() ) );
 	ltm->addWidget( cbox );
-	ltm->addSpacing( 5 );
 	
 	// gravity 
-	cbox = checkGravity = new QCheckBox( i18n("Gravity"), this );
+	cbox = checkGravity = new QCheckBox( i18n("Gravity"), main );
 	cbox->setChecked( gravity[mode] );
-	cbox->adjustSize();
-	cbox->setMinimumSize( cbox->sizeHint() );
 	connect( cbox, SIGNAL( clicked() ), SLOT( slotGravity() ) );
 	ltm->addWidget( cbox );
-	ltm->addSpacing( 5 );
 		
 	// hide background
-	cbox = checkHideBG = new QCheckBox( i18n("Hide background"), this );
+	cbox = checkHideBG = new QCheckBox( i18n("Hide background"), main );
 	cbox->setChecked( hideBG[mode] );
-	cbox->adjustSize();
-	cbox->setMinimumSize( cbox->sizeHint() );
 	connect( cbox, SIGNAL( clicked() ), SLOT( slotHideBG() ) );
 	ltm->addWidget( cbox );		
-	ltm->addStretch( 1 );
+	ltm->addStretch();
 		
 	// size 	
-	label = new QLabel( i18n("Size:"), this );
+	label = new QLabel( i18n("Size:"), main );
 	ltc->addWidget( label );
 		
-	sb = slideSize = new QSlider(9, 50, 5, size[mode], QSlider::Horizontal,
-                                this );
-	sb->setMinimumSize( 90, 20 );
-    sb->setTickmarks(QSlider::Below);
-    sb->setTickInterval(5);
-	connect( sb, SIGNAL( sliderMoved( int ) ), SLOT( slotSize( int ) ) );
-	connect( sb, SIGNAL( sliderPressed()    ), SLOT( slotSliderPressed() ) );
-	connect( sb, SIGNAL( sliderReleased()   ), SLOT( slotSliderReleased() ) );
+	slideSize = new QSlider(9, 50, 5, size[mode], QSlider::Horizontal,
+                                main );
+	slideSize->setMinimumSize( 90, 20 );
+    slideSize->setTickmarks(QSlider::Below);
+    slideSize->setTickInterval(5);
+	connect( slideSize, SIGNAL( sliderMoved( int ) ),
+		SLOT( slotSize( int ) ) );
+	connect( slideSize, SIGNAL( sliderPressed() ),
+		SLOT( slotSliderPressed() ) );
+	connect( slideSize, SIGNAL( sliderReleased() ),
+		SLOT( slotSliderReleased() ) );
 
-	ltc->addWidget( sb );
-	ltc->addSpacing( 3 );
+	ltc->addWidget( slideSize );
 
 	// intensity
-	label = new QLabel( i18n("Intensity:"), this );
+	label = new QLabel( i18n("Intensity:"), main );
 	ltc->addWidget( label );
 		
-	sb = slideIntensity = new QSlider(0, 10, 1, intensity[mode],
-                                     QSlider::Horizontal, this );
-	sb->setMinimumSize( 90, 20 );
-    sb->setTickmarks(QSlider::Below);
-    sb->setTickInterval(1);
-	connect( sb, SIGNAL( sliderMoved( int ) ), SLOT( slotIntensity( int )) );
-	connect( sb, SIGNAL( sliderPressed()    ), SLOT( slotSliderPressed() ) );
-	connect( sb, SIGNAL( sliderReleased()   ), SLOT( slotSliderReleased() ) );
-	ltc->addWidget( sb );
-	ltc->addSpacing( 3 );
+	slideIntensity = new QSlider(0, 10, 1, intensity[mode],
+                                     QSlider::Horizontal, main );
+	slideIntensity->setMinimumSize( 90, 20 );
+    slideIntensity->setTickmarks(QSlider::Below);
+    slideIntensity->setTickInterval(1);
+	connect( slideIntensity, SIGNAL( sliderMoved( int ) ),
+		SLOT( slotIntensity( int )) );
+	connect( slideIntensity, SIGNAL( sliderPressed() ),
+		SLOT( slotSliderPressed() ) );
+	connect( slideIntensity, SIGNAL( sliderReleased() ),
+		SLOT( slotSliderReleased() ) );
+	ltc->addWidget( slideIntensity );
 
 	// speed
-	label = new QLabel( i18n("Speed:"), this );
+	label = new QLabel( i18n("Speed:"), main );
 	ltc->addWidget( label );
 	
-	sb = slideSpeed = new QSlider(0, SCI_MAX_SPEED, 10, speed[mode],
-                             QSlider::Horizontal, this );
-	sb->setMinimumSize( 90, 20 );
-    sb->setTickmarks(QSlider::Below);
-    sb->setTickInterval(10);
-	connect( sb, SIGNAL( sliderMoved( int ) ), SLOT( slotSpeed( int ) ) );
-	ltc->addWidget( sb );
-	ltc->addSpacing( 3 );
+	slideSpeed = new QSlider(0, SCI_MAX_SPEED, 10, speed[mode],
+                             QSlider::Horizontal, main );
+	slideSpeed->setMinimumSize( 90, 20 );
+    slideSpeed->setTickmarks(QSlider::Below);
+    slideSpeed->setTickInterval(10);
+	connect( slideSpeed, SIGNAL( sliderMoved( int ) ),
+		SLOT( slotSpeed( int ) ) );
+	ltc->addWidget( slideSpeed );
 
 	// motion
-	label = new QLabel( i18n("Motion:"), this );
+	label = new QLabel( i18n("Motion:"), main );
 	ltc->addWidget( label );
 
-	QHBoxLayout *ltcm = new QHBoxLayout() ;
+	QHBoxLayout *ltcm = new QHBoxLayout;
 	ltc->addLayout( ltcm );
 	
-	sb = slideMoveX = new QSlider(0, SCI_MAX_MOVE, 5, moveX[mode],
-                                 QSlider::Horizontal, this );
-	sb->setMinimumSize( 40, 20 );
-    sb->setTickmarks(QSlider::Below);
-    sb->setTickInterval(5);
-	connect( sb, SIGNAL( sliderMoved( int ) ), SLOT( slotMoveX( int ) ) );
-	ltcm->addWidget( sb );
+	slideMoveX = new QSlider(0, SCI_MAX_MOVE, 5, moveX[mode],
+                                 QSlider::Horizontal, main );
+	slideMoveX->setMinimumSize( 40, 20 );
+    slideMoveX->setTickmarks(QSlider::Below);
+    slideMoveX->setTickInterval(5);
+	connect( slideMoveX, SIGNAL( sliderMoved( int ) ),
+		SLOT( slotMoveX( int ) ) );
+	ltcm->addWidget( slideMoveX );
 
-	sb = slideMoveY = new QSlider(0, SCI_MAX_MOVE, 5, moveY[mode],
-                                QSlider::Horizontal, this );
-	sb->setMinimumSize( 40, 20 );
-    sb->setTickmarks(QSlider::Below);
-    sb->setTickInterval(5);
-	connect( sb, SIGNAL( sliderMoved( int ) ), SLOT( slotMoveY( int ) ) );
-	ltcm->addWidget( sb );		
+	slideMoveY = new QSlider(0, SCI_MAX_MOVE, 5, moveY[mode],
+                                QSlider::Horizontal, main );
+	slideMoveY->setMinimumSize( 40, 20 );
+    slideMoveY->setTickmarks(QSlider::Below);
+    slideMoveY->setTickInterval(5);
+	connect( slideMoveY, SIGNAL( sliderMoved( int ) ),
+		SLOT( slotMoveY( int ) ) );
+	ltcm->addWidget( slideMoveY );
 
-	ltc->addStretch( 1 );
+	ltc->addStretch();
 
 	// preview
-	preview = new KPreviewWidget( this );
+	preview = new KPreviewWidget( main );
 	preview->setFixedSize( 220, 170 );
 	QPixmap p( locate("data", "kscreensaver/pics/kscience.png") );
 	if( p.isNull() )
@@ -997,23 +977,8 @@ KScienceSetup::KScienceSetup(  QWidget *parent, const char *name ) :
 	else
 		preview->setBackgroundPixmap( p );
 	preview->show();	// otherwise saver does not get correct size
-	ltu->addWidget( preview );
+	lt->addWidget( preview );
 
-	// buttons
-	KButtonBox *bbox = new KButtonBox( this );
-	button = bbox->addButton( i18n("&About") );
-	connect( button, SIGNAL( clicked() ), SLOT( slotAbout() ) );
-	bbox->addStretch( 1 );
-
-	button = bbox->addButton( i18n("&OK") );
-	connect( button, SIGNAL( clicked() ), SLOT( slotOkPressed() ) );
-
-	button = bbox->addButton( i18n("&Cancel") );
-	connect( button, SIGNAL( clicked() ), SLOT( reject() ) );
-	bbox->layout();
-	lt->addWidget( bbox );
-	
-	lt->freeze();
 	// let the preview window display before creating the saver
 	kapp->processEvents();
 
@@ -1045,7 +1010,7 @@ void KScienceSetup::readSettings()
 {
     KConfig *config = KGlobal::config();
         QString sMode;
-  
+
 	config->setGroup( "Settings" );
 	mode = config->readNumEntry( "ModeNr", SCI_DEFAULT_MODE );
 
@@ -1062,7 +1027,7 @@ void KScienceSetup::readSettings()
 		gravity[i]   = config->readBoolEntry( "Gravity",   SCI_DEFAULT_GRAVITY);
 		hideBG[i]    = config->readBoolEntry( "HideBG",    SCI_DEFAULT_HIDE);
 	}
-}  
+}
 
 void KScienceSetup::slotMode( int m )
 {
@@ -1114,7 +1079,6 @@ void KScienceSetup::slotMoveY( int y )
 		saver->setMoveY( y );
 }
 
-   
 void KScienceSetup::slotSize( int s )
 {
 	size[mode] = s;
@@ -1130,7 +1094,7 @@ void KScienceSetup::slotSpeed( int s )
 	if( saver )
 		saver->setSpeed( s );
 }
-                       
+
 void KScienceSetup::slotIntensity( int i )
 {
 	intensity[mode] = i;
@@ -1152,7 +1116,7 @@ void KScienceSetup::slotSliderReleased()
 }
 
 // Ok pressed - save settings and exit
-void KScienceSetup::slotOkPressed()
+void KScienceSetup::slotOk()
 {
     KConfig *config = KGlobal::config();
 	QString sSize, sSpeed, sIntensity, sMode;
@@ -1179,7 +1143,7 @@ void KScienceSetup::slotOkPressed()
 	accept();
 }
 
-void KScienceSetup::slotAbout()
+void KScienceSetup::slotHelp()
 {
 	QString about = i18n("Science Version 0.26.5\n\nWritten by Rene Beutler (1998)\nrbeutler@g26.ethz.ch");
 	KMessageBox::about(this,
