@@ -1,5 +1,8 @@
 /* Slide Show Screen Saver
  *  (C) 1999 Stefan Taferner <taferner@kde.org>
+ *  (C) 2001 Martin R. Jones <mjones@kde.org>
+ *  (C) 2003 Chris Howells <howells@kde.org>
+ *  (C) 2003 Sven Leiber <s.leiber@web.de>
  *
  * This code is under GPL
  *
@@ -8,7 +11,6 @@
 
 
 #include <qdir.h>
-#include <qpushbutton.h>
 #include <qcolor.h>
 #include <qlabel.h>
 #include <qlayout.h>
@@ -16,18 +18,20 @@
 #include <qpaintdevicemetrics.h>
 #include <qcheckbox.h>
 #include <qcombobox.h>
-#include <qslider.h>
+#include <qspinbox.h>
+#include <qframe.h>
 
 #include <kconfig.h>
 #include <kglobal.h>
 #include <kapplication.h>
 #include <klocale.h>
-#include <kbuttonbox.h>
 #include <kmessagebox.h>
 #include <kimageio.h>
 #include <kfiledialog.h>
 #include <kstandarddirs.h>
 #include <kurlrequester.h>
+#include <kaboutdata.h>
+#include <kaboutapplication.h>
 #include <kdebug.h>
 
 #include <stdlib.h>
@@ -37,13 +41,20 @@
 
 #include "slideshow.h"
 #include "slideshow.moc"
+#include "slideshowcfg.h"
+
+
+#define SLIDESHOW_VERSION "2.3.0"
+static const char *version = SLIDESHOW_VERSION;
+static const char *description = I18N_NOOP("KSlideshow");
+
 
 // libkscreensaver interface
 extern "C"
 {
     const char *kss_applicationName = "kslideshow.kss";
     const char *kss_description = I18N_NOOP( "KSlideshow" );
-    const char *kss_version = "2.2.0";
+    const char *kss_version = SLIDESHOW_VERSION;
 
     KScreenSaver *kss_create( WId id )
     {
@@ -95,6 +106,8 @@ kSlideShowSaver::kSlideShowSaver( WId id ): KScreenSaver(id)
 kSlideShowSaver::~kSlideShowSaver()
 {
   delete [] mIntArray;
+  delete [] mEffectList;
+
   mTimer.stop();
   if (mPainter.isActive()) mPainter.end();
   QColor::leaveAllocContext();
@@ -122,11 +135,12 @@ void kSlideShowSaver::readConfig()
   mShowRandom = config->readBoolEntry("ShowRandom", true);
   mZoomImages = config->readBoolEntry("ZoomImages", false);
   mPrintName = config->readBoolEntry("PrintName", true);
-  mDirectory = config->readEntry("Directory", KGlobal::dirs()->saveLocation("data", "kslideshow/pics", false));
+  mDirectory = config->readPathEntry("Directory", QDir::homeDirPath());
   mDelay = config->readNumEntry("Delay", 10) * 1000;
+  mSubdirectory = config->readBoolEntry("SubDirectory", false);
+  mRandomPosition = config->readBoolEntry("RandomPosition", false);
 
   loadDirectory();
-  // loadFileList("slideshow.list");
 }
 
 
@@ -742,11 +756,37 @@ void kSlideShowSaver::createNextScreen()
     }
     else
     {
-      x = (ww - iw) >> 1;
-      y = (wh - ih) >> 1;
+      if(iw > ww || ih > wh)
+      {
+        fx = (double)ww / iw;
+	fy = (double)wh / ih;
+	if (fx > fy) fx = fy;
+	if (fx > 2) fx = 2;
+	iw = (int)(iw * fx);
+	ih = (int)(ih * fx);
+	QImage scaledImg = mImage.smoothScale(iw, ih);
 
-      // bitBlt(&mNextScreen, x, y, &mImage, 0, 0, iw, ih, CopyROP, false);
-      p.drawImage(x, y, mImage);
+	x = (ww - iw) >> 1;
+	y = (wh - ih) >> 1;
+
+	p.drawImage(x, y, scaledImg);
+      }
+      else
+      {
+        if(mRandomPosition)
+        {
+          x = rand() % (ww - iw);
+          y = rand() % (wh - ih);
+        }
+        else
+        {
+          x = (ww - iw) >> 1;
+          y = (wh - ih) >> 1;
+        }
+
+        // bitBlt(&mNextScreen, x, y, &mImage, 0, 0, iw, ih, CopyROP, false);
+        p.drawImage(x, y, mImage);
+      }
     }
 
     if (mPrintName)
@@ -767,21 +807,23 @@ void kSlideShowSaver::createNextScreen()
 //----------------------------------------------------------------------------
 void kSlideShowSaver::loadNextImage()
 {
-  QString fname, fpath;
-  int num, i, j;
+  QString fname;
+  int num;
 
   if (mShowRandom)
   {
-    num = mRandomList.count();
-    if (num <= 0)
+    num = mFileList.count();
+    if (num <= 0) //no files in the directory
     {
-      mRandomList = mFileList;
-      num = mRandomList.count();
+      return;
     }
-    if (num <= 0) return;
     mFileIdx = rand() % num;
-    fname = mRandomList[mFileIdx];
-    mRandomList.remove(fname);
+    fname = mFileList[mFileIdx];
+    mFileList.remove(fname);
+    if (num == 1) //we're about to run out of images
+    {
+      mFileList = mRandomList;
+    }
   }
   else
   {
@@ -790,19 +832,17 @@ void kSlideShowSaver::loadNextImage()
     fname = mFileList[mFileIdx];
   }
 
-  if (!mDirectory.isEmpty()) fpath = mDirectory + '/' + fname;
-  else fpath = fname;
-
-  if (!mImage.load(fpath))
+  if (!mImage.load(fname))
   {
-    kdDebug() << "Failed to load image " << fpath << endl;
+    kdDebug() << "Failed to load image " << fname << endl;
     mFileList.remove(fname);
-    mRandomList.remove(fname);
-    if (!mFileList.isEmpty()) loadNextImage();
+    if (!mFileList.isEmpty())
+        loadNextImage();
     return;
   }
   mFileIdx++;
 
+  int i, j;
   i = fname.findRev('.');
   if (i < 0) i = 32767;
   j = fname.findRev('/') + 1;
@@ -814,37 +854,40 @@ void kSlideShowSaver::loadNextImage()
 //----------------------------------------------------------------------------
 void kSlideShowSaver::loadDirectory()
 {
-  QDir dir(mDirectory);
-
   mFileIdx = 0;
   mFileList.clear();
-  mFileList = dir.entryList();
-  mFileList.remove(".");
-  mFileList.remove("..");
+  traverseDirectory(mDirectory);
+  mRandomList = mFileList;
 }
 
-
-//----------------------------------------------------------------------------
-void kSlideShowSaver::loadFileList(const QCString& aFileName)
+void kSlideShowSaver::traverseDirectory(const QString &dirName)
 {
-  QFile file(aFileName);
-  QString fname;
+  QDir dir(dirName);
+  dir.setFilter(QDir::Dirs | QDir::Files | QDir::NoSymLinks);
 
-  mFileList.clear();
-  mFileIdx = 0;
-
-  if (!file.open(IO_ReadOnly)) return;
-
-  while (!file.atEnd())
+  const QFileInfoList *fileinfolist = dir.entryInfoList();
+  QFileInfoListIterator it(*fileinfolist);
+  QFileInfo *fi;
+  while ((fi = it.current()))
   {
-    if (file.readLine(fname, 256) > 0)
-    {
-      fname = fname.stripWhiteSpace();
-      if (fname.isEmpty() || fname[0] == '#') continue;
-      mFileList.append(fname);
-    }
-  }
-  file.close();
+     if (fi->fileName() == "." || fi->fileName() == "..")
+     {
+        ++it;
+        continue;
+     }
+     if (fi->isDir() && fi->isReadable() && mSubdirectory)
+     {
+        traverseDirectory(fi->filePath());
+     }
+     else
+     {
+        if (!fi->isDir())
+        {
+           mFileList.append(fi->filePath().data());
+        }
+     }
+  ++it;
+   }
 }
 
 
@@ -858,102 +901,51 @@ void kSlideShowSaver::blank()
 //=============================================================================
 //  Class kSlideShowSetup
 //=============================================================================
-kSlideShowSetup::kSlideShowSetup(QWidget *aParent, const char *aName):
-  QDialog(aParent, aName, TRUE )
+kSlideShowSetup::kSlideShowSetup(QWidget *aParent, const char *aName)
+  : KDialogBase(aParent, aName, true, i18n( "Setup Slide Show Screen Saver" ),
+    Ok|Cancel|Help, Ok, true )
 {
-  setCaption(i18n("Setup Slide Show Screen Saver"));
+  setButtonText( Help, i18n( "A&bout" ) );
 
-  QPushButton *button;
-  mSaver = NULL;
+  QWidget *main = makeMainWidget();
+  QVBoxLayout *top = new QVBoxLayout( main, 0, spacingHint() );
 
-  QVBoxLayout *tl = new QVBoxLayout(this, 10, 10);
-  QHBoxLayout *tl1 = new QHBoxLayout;
-  tl->addLayout(tl1);
-  QVBoxLayout *tl11 = new QVBoxLayout(5);
-  tl1->addLayout(tl11);
+  cfg = new SlideShowCfg( main, "SlideShowCfg" );
+  top->addWidget( cfg );
+  top->addStretch();
 
-  mCbxZoom = new QCheckBox(i18n("Zoom pictures"), this);
-  connect(mCbxZoom, SIGNAL(clicked()), SLOT(writeSettings()));
-  tl11->addWidget(mCbxZoom);
+  cfg->mPreview->setFixedSize(220, 170);
+  cfg->mPreview->setBackgroundColor(black);
+  cfg->mPreview->show();    // otherwise saver does not get correct size
+  mSaver = new kSlideShowSaver(cfg->mPreview->winId());
 
-  mCbxRandom = new QCheckBox(i18n("Random play"), this);
-  connect(mCbxRandom, SIGNAL(clicked()), SLOT(writeSettings()));
-  tl11->addWidget(mCbxRandom);
-
-  mCbxShowName = new QCheckBox(i18n("Show names"), this);
-  connect(mCbxShowName, SIGNAL(clicked()), SLOT(writeSettings()));
-  tl11->addWidget(mCbxShowName);
-  tl11->addSpacing(5);
-
-  mLblDelay = new QLabel(i18n("Delay:"), this);
-  mLblDelay->setMaximumWidth(32767);
-  tl11->addWidget(mLblDelay);
-
-  mDelay = new QSlider(1, 60, 10, 1, QSlider::Horizontal, this);
-  mDelay->setMinimumSize(90, 20);
-  mDelay->setTracking(false);
-  mDelay->setTickmarks(QSlider::Right);
-  mDelay->setTickInterval(10);
-  connect(mDelay, SIGNAL(sliderMoved (int)), SLOT(slotDelay(int)));
-  tl11->addWidget(mDelay);
-  tl11->addSpacing(5);
-
-  tl11->addStretch(1000);
-
-  mPreview = new QWidget(this);
-  mPreview->setFixedSize(220, 170);
-  mPreview->setBackgroundColor(black);
-  mPreview->show();    // otherwise saver does not get correct size
-  mSaver = new kSlideShowSaver(mPreview->winId());
-  tl1->addWidget(mPreview);
-
-	
-	mDirChooser = new KURLRequester(this);
-	mDirChooser->setMode(KFile::Directory | KFile::ExistingOnly);
-  connect(mDirChooser, SIGNAL(returnPressed(const QString &)), SLOT(slotDirSelected(const QString &)));
-  connect(mDirChooser, SIGNAL(urlSelected(const QString &)), SLOT(slotDirSelected(const QString &)));
-  tl->addWidget(mDirChooser);
-  //  tl->addSpacing(5);
-
-  KButtonBox *bbox = new KButtonBox(this);
-  button = bbox->addButton(i18n("&About"));
-  connect(button, SIGNAL(clicked()), SLOT(slotAbout()));
-  bbox->addStretch(1);
-
-  button = bbox->addButton(i18n("&OK"));
-  connect(button, SIGNAL(clicked()), SLOT(slotOkPressed()));
-
-  button = bbox->addButton(i18n("&Cancel"));
-  connect(button, SIGNAL(clicked()), SLOT(reject()));
-  bbox->layout();
-  tl->addWidget(bbox);
-
-  tl->freeze();
+  cfg->mDirChooser->setMode(KFile::Directory | KFile::ExistingOnly);
+  connect(cfg->mDirChooser, SIGNAL(returnPressed(const QString &)),
+      SLOT(slotDirSelected(const QString &)));
+  connect(cfg->mDirChooser, SIGNAL(urlSelected(const QString &)),
+      SLOT(slotDirSelected(const QString &)));
 
   readSettings();
 }
 
+kSlideShowSetup::~kSlideShowSetup()
+{
+    delete mSaver;
+}
 
 //-----------------------------------------------------------------------------
 void kSlideShowSetup::readSettings()
 {
-  int num;
-  QString dirname;
   KConfig *config = KGlobal::config();
 
   config->setGroup("Settings");
-  mCbxRandom->setChecked(config->readBoolEntry("ShowRandom", true));
-  mCbxZoom->setChecked(config->readBoolEntry("ZoomImages", false));
-  mCbxShowName->setChecked(config->readBoolEntry("PrintName", true));
-  num = config->readNumEntry("Delay", 20);
-  mDelay->setValue(num);
-
-  QString str = i18n("Delay: %1 seconds").arg(num);
-  mLblDelay->setText(str);
-
-  dirname = config->readEntry("Directory");
-
-	mDirChooser->setURL(dirname);
+  cfg->mCbxRandom->setChecked(config->readBoolEntry("ShowRandom", true));
+  cfg->mCbxZoom->setChecked(config->readBoolEntry("ZoomImages", false));
+  cfg->mCbxShowName->setChecked(config->readBoolEntry("PrintName", true));
+  cfg->mDelay->setValue(config->readNumEntry("Delay", 20));
+  cfg->mDirChooser->setURL(config->readPathEntry("Directory"));
+  cfg->mCbxSubdirectory->setChecked(config->readBoolEntry("SubDirectory", false));
+  cfg->mCbxRandomPosition->setChecked(config->readBoolEntry("RandomPosition", false));
 }
 
 
@@ -963,12 +955,13 @@ void kSlideShowSetup::writeSettings()
   KConfig *config = KGlobal::config();
 
   config->setGroup("Settings");
-  config->writeEntry("ShowRandom", mCbxRandom->isChecked());
-  config->writeEntry("ZoomImages", mCbxZoom->isChecked());
-  config->writeEntry("PrintName",  mCbxShowName->isChecked());
-  config->writeEntry("Delay", mDelay->value());
-
-  config->writeEntry("Directory", mDirChooser->url());
+  config->writeEntry("ShowRandom", cfg->mCbxRandom->isChecked());
+  config->writeEntry("ZoomImages", cfg->mCbxZoom->isChecked());
+  config->writeEntry("PrintName",  cfg->mCbxShowName->isChecked());
+  config->writeEntry("Delay", cfg->mDelay->value());
+  config->writePathEntry("Directory", cfg->mDirChooser->url());
+  config->writeEntry("SubDirectory", cfg->mCbxSubdirectory->isChecked());
+  config->writeEntry("RandomPosition", cfg->mCbxRandomPosition->isChecked());
 
   config->sync();
 
@@ -980,16 +973,6 @@ void kSlideShowSetup::writeSettings()
 }
 
 
-//-----------------------------------------------------------------------------
-void kSlideShowSetup::slotDelay(int x)
-{
-  writeSettings();
-
-  QString str = i18n("Delay: %1 seconds").arg(x);
-  mLblDelay->setText(str);
-}
-
-
 //-----------------------------------------------------------------------------
 void kSlideShowSetup::slotDirSelected(const QString &)
 {
@@ -998,7 +981,7 @@ void kSlideShowSetup::slotDirSelected(const QString &)
 
 
 //-----------------------------------------------------------------------------
-void kSlideShowSetup::slotOkPressed()
+void kSlideShowSetup::slotOk()
 {
   writeSettings();
   accept();
@@ -1006,18 +989,15 @@ void kSlideShowSetup::slotOkPressed()
 
 
 //-----------------------------------------------------------------------------
-void kSlideShowSetup::slotAbout()
+void kSlideShowSetup::slotHelp()
 {
-  KMessageBox::about(this,
-     i18n("SlideShow Version 1.1\n\n"
-			"Copyright (c) 1999 by\n"
-			"Stefan Taferner <taferner@kde.org>\n"));
+  KAboutData aboutData( "kslideshow.kss", I18N_NOOP("SlideShow"),
+                       version, description, KAboutData::License_GPL,
+                       "(c) 1999-2003, The KDE Team" );
+  aboutData.addAuthor("Stefan Taferner", 0, "taferner@kde.org");
+  aboutData.addAuthor("Chris Howells", 0, "howells@kde.org");
+  aboutData.addAuthor("Sven Leiber", 0, "s.leiber@web.de");
+
+  KAboutApplication mAbout(&aboutData, this, 0);
+  mAbout.exec();
 }
-
-
-//-----------------------------------------------------------------------------
-void kSlideShowSetup::minSize(QWidget* aWidget)
-{
-  aWidget->setFixedSize(aWidget->sizeHint());
-}
-
