@@ -69,6 +69,12 @@ KWaveSetup::KWaveSetup( QWidget *parent, const char *name )
 
 }
 
+KWaveSetup::~KWaveSetup( )
+{
+    delete saver;
+}
+
+
 // read settings from config file
 void KWaveSetup::readSettings()
 {
