@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
 #include <stdlib.h>
@@ -87,7 +87,7 @@ void exitHandler( int )
 
 
 KPartSaver::KPartSaver( WId id )
-    : KScreenSaver( id ), m_timer(), m_part(0), m_current(-1), m_back(0), m_factory(0)
+    : KScreenSaver( id ), m_timer(), m_part(0), m_current(-1), m_factory(0), m_back(0)
 {
     // install signal handlers to make sure that nspluginviewer is shutdown correctly
     // move this into the nspluginviewer kpart code
@@ -161,10 +161,8 @@ void KPartSaver::closeURL()
         m_part = 0;
     }
 
-    if( !m_factory ) {
-        delete m_factory;
-        m_factory = 0;
-    }
+    delete m_factory;
+    m_factory = 0;
 }
 
 
