@@ -23,13 +23,10 @@
 
 #include "demowin.h"
 #include "saver.h"
-#include <kscreensaver_vroot.h>
 
-static const char *appName = "klock";
-
-static const char *description = I18N_NOOP("KDE Screen Lock/Saver");
-
-static const char *version = "2.0.0";
+static const char appName[] = "klock";
+static const char description[] = I18N_NOOP("KDE Screen Lock/Saver");
+static const char version[] = "2.0.0";
 
 static const KCmdLineOptions options[] =
 {
@@ -37,7 +34,7 @@ static const KCmdLineOptions options[] =
   { "window-id wid", I18N_NOOP("Run in the specified XWindow."), 0 },
   { "root", I18N_NOOP("Run in the root XWindow."), 0 },
   { "demo", I18N_NOOP("Start screen saver in demo mode."), "default"},
-  { 0,0,0 }
+  KCmdLineLastOption
 };
 
 static void crashHandler( int sig )
@@ -78,7 +75,7 @@ int main(int argc, char *argv[])
 
     if (args->isSet("root"))
     {
-        saveWin = RootWindow(qt_xdisplay(), qt_xscreen());
+        saveWin = QApplication::desktop()->handle();
     }
 
     if (args->isSet("demo"))
