@@ -21,6 +21,7 @@
 #include <qvaluevector.h>
 #include <qobject.h>
 
+class QListView;
 class QPushButton;
 class QSignalMapper;
 class QCheckBox;
@@ -49,32 +50,42 @@ protected slots:
 	void slotColorButtonChanged(const QColor&);
 	void slotTitlebarGradientTypeChanged(int);
 	void slotResizeHandleCheckBoxChanged();
+	void slotThemeListViewSelectionChanged ();
 
+private slots:
+	void slotLoadThemeList ();
+	
 private:
-	enum ButtonType{stickyButton, helpButton, iconifyButton, maximizeButton, closeButton };
+	enum ButtonType{stickyButton, helpButton, iconifyButton,
+		maximizeButton, closeButton };
+
+	KConfig *_glowConfig;
+
+	bool _showResizeHandle;
+	KPixmapEffect::GradientType _titlebarGradientType;
+	QString _theme_name;
+
+	QWidget *_main_group_box;
+	QGroupBox *_button_glow_color_group_box;
+	QGroupBox *_theme_group_box;
+
+	QListView * _theme_list_view;
+
+	QCheckBox *_showResizeHandleCheckBox;
+	QComboBox *_titlebarGradientTypeComboBox;
+
+	QPushButton *_stickyButton;
+	QPushButton *_helpButton;
+	QPushButton *_iconifyButton;
+	QPushButton *_maximizeButton;
+	QPushButton *_closeButton;
+	QSignalMapper *_titleButtonMapper;
+
+	QColor* _buttonConfigMap;
+	QValueVector<QPushButton*> _titleButtonList;
 	
-	KConfig *m_glowConfig;
-
-	bool m_showResizeHandle;
-	KPixmapEffect::GradientType m_titlebarGradientType;
-
-	QGroupBox *m_mainGroupBox;
-	QGroupBox *m_buttonGlowColorGroupBox;
-
-	QCheckBox *m_showResizeHandleCheckBox;
-	QComboBox *m_titlebarGradientTypeComboBox;
-
-	QPushButton *m_stickyButton;
-	QPushButton *m_helpButton;
-	QPushButton *m_iconifyButton;
-	QPushButton *m_maximizeButton;
-	QPushButton *m_closeButton;
-	QSignalMapper *m_titleButtonMapper;
-
-	QColor* m_buttonConfigMap;
-	QValueVector<QPushButton*> m_titleButtonList;
-	
-	KColorButton *m_colorButton;
+	KColorButton *_colorButton;
 };
 
 #endif
+
