@@ -20,23 +20,63 @@
 
 #include <vector>
 #include <map>
-#include <kwin/client.h>
-#include <kwin/kwinbutton.h>
+#include <kdecoration.h>
+#include <kdecorationfactory.h>
 
 class QPixmap;
 class QBitmap;
 class QTimer;
+class QBoxLayout;
+class QGridLayout;
 class QVBoxLayout;
 class QSpacerItem;
 
 namespace Glow
 {
 
-using namespace KWinInternal;
-
 class GlowButton;
 class GlowButtonFactory;
 
+//-----------------------------------------------------------------------------
+// GlowTheme
+//-----------------------------------------------------------------------------
+
+struct GlowTheme
+{
+	QSize buttonSize;
+	
+	QString backgroundPixmap;
+	QString backgroundAlphaPixmap;
+
+	QString stickyOnPixmap;
+	QString stickyOffPixmap;
+	QString maximizeOnPixmap;
+	QString maximizeOffPixmap;
+	QString helpPixmap;
+	QString closePixmap;
+	QString iconifyPixmap;
+
+	QString stickyOnGlowPixmap;
+	QString stickyOffGlowPixmap;
+	QString maximizeOnGlowPixmap;
+	QString maximizeOffGlowPixmap;
+	QString helpGlowPixmap;
+	QString closeGlowPixmap;
+	QString iconifyGlowPixmap;
+};
+
+static GlowTheme default_glow_theme = {
+	QSize (17, 17),
+	"background.png", "background_alpha.png",
+	"stickyon.png", "stickyoff.png",
+	"maximizeon.png", "maximizeoff.png",
+	"help.png", "close.png", "iconify.png",
+	"stickyon_glow.png", "stickyoff_glow.png",
+	"maximizeon_glow.png", "maximizeoff_glow.png",
+	"help_glow.png", "close_glow.png", "iconify_glow.png" };
+
+//-----------------------------------------------------------------------------
+// GlowClientConfig
 //-----------------------------------------------------------------------------
 
 class GlowClientConfig
@@ -44,7 +84,7 @@ class GlowClientConfig
 public:
 	GlowClientConfig();
 
-	void load();
+	void load (KDecorationFactory *factory);
 
 	QColor stickyButtonGlowColor;
 	QColor helpButtonGlowColor;
@@ -53,60 +93,78 @@ public:
 	QColor closeButtonGlowColor;
 	bool showResizeHandle;
 	int titlebarGradientType;
+	QString themeName;
 };
 
+//-----------------------------------------------------------------------------
+// GlowClientGlobals
 //-----------------------------------------------------------------------------
 
-class GlowClientGlobals : public QObject
+class GlowClientGlobals : public KDecorationFactory
 {
-	Q_OBJECT
 public:
 	enum PixmapType { StickyOn, StickyOff, Help, Iconify, MaximizeOn,
 		MaximizeOff, Close };
 
 	static GlowClientGlobals *instance();
-
+	
 	~GlowClientGlobals();
 
-	QString getPixmapName(PixmapType type, bool isActive, bool isLeft, bool isSmall);
+	virtual KDecoration* createDecoration( KDecorationBridge* b );
+	virtual bool reset( unsigned long changed );
+	QValueList< GlowClientGlobals::BorderSize >  borderSizes() const;
 	
-	void reset();
+	QString getPixmapName(PixmapType type, bool isActive);
 
-	GlowClientConfig *config;
-	GlowButtonFactory *buttonFactory;
+	GlowTheme * theme() const { return _theme; }
+	GlowClientConfig * config() const { return _config; }
+	GlowButtonFactory * buttonFactory() { return _button_factory; }
 
 private:
 	static GlowClientGlobals *m_instance;
+	
+	GlowTheme * _theme;
+	GlowClientConfig * _config;
+	GlowButtonFactory * _button_factory;
 
 	GlowClientGlobals();
-
 	void readConfig();
-	void createPixmaps();
+	void readTheme ();
+	bool createPixmaps();
 	void deletePixmaps();
-	void createPixmap(PixmapType type, bool isActive, bool isLeft, bool isSmall);
+	bool createPixmap(PixmapType type,bool isActive);
 	const QString getPixmapTypeName(PixmapType type);
 };
 
+//-----------------------------------------------------------------------------
+// GlowClient
 //-----------------------------------------------------------------------------
 
-class GlowClient : public Client
+class GlowClient : public KDecoration
 {
 	Q_OBJECT
 public:
-	GlowClient( KWinInternal::Workspace *ws, WId w,
-		QWidget *parent=0, const char* name=0 );
+	GlowClient( KDecorationBridge* b, KDecorationFactory* f );
 	~GlowClient();
+	
+	virtual void init();
+	virtual void borders( int&, int&, int&, int& ) const;
+	virtual void resize( const QSize& );
+	virtual QSize minimumSize() const;
 
 protected:
 	virtual void resizeEvent( QResizeEvent * );
 	virtual void paintEvent( QPaintEvent * );
 	virtual void showEvent( QShowEvent * );
 	virtual void mouseDoubleClickEvent( QMouseEvent * );
-	virtual void maximizeChange(bool m);
-	virtual void activeChange(bool);
+	virtual void maximizeChange();
+	virtual void activeChange();
 	virtual void iconChange();
-	virtual void stickyChange(bool on);
-	virtual MousePosition mousePosition(const QPoint &) const;
+	virtual void desktopChange();
+	virtual void shadeChange();
+	virtual void captionChange();
+	virtual Position mousePosition(const QPoint &) const;
+	virtual bool eventFilter( QObject* o, QEvent* e );
 
 private:
 	std::vector<GlowButton*> m_buttonList;
@@ -117,10 +175,11 @@ private:
 	GlowButton *m_minimizeButton;
 	GlowButton *m_maximizeButton;
 	GlowButton *m_closeButton;
-	QVBoxLayout *m_mainLayout;
 	QBoxLayout *m_leftButtonLayout;
 	QBoxLayout *m_rightButtonLayout;
-	QSpacerItem *m_titleSpacer;
+	QSpacerItem * _bottom_spacer;
+	QSpacerItem * _title_spacer;
+	QVBoxLayout * _main_layout;
 
 	void createButtons();
 	void updateButtonPositions();
@@ -136,7 +195,7 @@ private:
 	bool isRight(GlowButton *button);
 
 protected slots:
-	void slotMaximize(int button);
+	void slotMaximize();
 };
 
 } // namespace
